@@ -46,7 +46,7 @@ def remove(cfg, snapshot_ids = None, force = None):
     sids = [selectSnapshot(snapshotsList, cfg, sid, 'SnapshotID to remove') for sid in snapshot_ids]
 
     if not force:
-        print('Do you really want to remove this snapshots?')
+        print('Do you really want to remove these snapshots?')
         [print(sid.displayName) for sid in sids]
         if not 'yes' == input('(no/yes): '):
             return
@@ -97,7 +97,7 @@ def checkConfig(cfg, crontab = True):
             return False
         okay()
 
-    test = 'Check/prepair snapshot path'
+    test = 'Check/prepare snapshot path'
     announceTest()
     snapshots_path = cfg.snapshotsPath(mode = mode, tmp_mount = True)
 
