@@ -18,9 +18,9 @@
 
 """Configuration logic.
 
-This module and its `Config` class contain the appliation logic handling the
+This module and its `Config` class contain the application logic handling the
 configuration of Back In Time. The handling of the configuration file itself
-is separated in the module :py:module:`configfile`.
+is separated in the module :py:mod:`configfile`.
 
 Development notes:
     Some of the methods have code comments starting with `#? ` instead of
@@ -32,7 +32,6 @@ Development notes:
 import os
 import sys
 import datetime
-import gettext
 import socket
 import random
 import shlex
@@ -42,6 +41,16 @@ except ImportError:
     import getpass
     pwd = None
 
+# Workaround: Mostly relevant on TravisCI but not exclusively.
+# While unittesting and without regular invocation of BIT the GNU gettext
+# class-based API isn't setup yet.
+# The bigger problem with config.py is that it do use translatable strings.
+# Strings like this do not belong into a config file or its context.
+try:
+    _('Warning')
+except NameError:
+    _ = lambda val: val
+
 import tools
 import configfile
 import logger
@@ -54,20 +63,15 @@ from exceptions import PermissionDeniedByPolicy, \
                        InvalidCmd, \
                        LimitExceeded
 
-_ = gettext.gettext
-
-gettext.bindtextdomain('backintime', os.path.join(tools.sharePath(), 'locale'))
-gettext.textdomain('backintime')
-
 
 class Config(configfile.ConfigFileWithProfiles):
     APP_NAME = 'Back In Time'
-    VERSION = '1.3.3-dev'
-    COPYRIGHT = 'Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, ' \
-                'Richard Bailey, Germar Reitze'
+    VERSION = '1.4.3'
+    COPYRIGHT = 'Copyright (C) 2008-2024 Oprea Dan, Bart de Koning, ' \
+                'Richard Bailey, Germar Reitze, Christian Buhtz, Michael Büker, Jürgen Altfeld et al.'
 
     CONFIG_VERSION = 6
-    """Latest or highest possible version of Backin Time's config file."""
+    """Latest or highest possible version of Back in Time's config file."""
 
     NONE = 0
     AT_EVERY_BOOT = 1
@@ -91,48 +95,35 @@ class Config(configfile.ConfigFileWithProfiles):
     DISK_UNIT_MB = 10
     DISK_UNIT_GB = 20
 
-    SCHEDULE_MODES = {
-                NONE: _('Disabled'),
-                AT_EVERY_BOOT: _('At every boot/reboot'),
-                _5_MIN: _('Every 5 minutes'),
-                _10_MIN: _('Every 10 minutes'),
-                _30_MIN: _('Every 30 minutes'),
-                _1_HOUR: _('Every hour'),
-                _2_HOURS: _('Every 2 hours'),
-                _4_HOURS: _('Every 4 hours'),
-                _6_HOURS: _('Every 6 hours'),
-                _12_HOURS: _('Every 12 hours'),
-                CUSTOM_HOUR: _('Custom Hours'),
-                DAY: _('Every Day'),
-                REPEATEDLY: _('Repeatedly (anacron)'),
-                UDEV: _('When drive get connected (udev)'),
-                WEEK: _('Every Week'),
-                MONTH: _('Every Month'),
-                YEAR: _('Every Year')
-                }
-
-    REMOVE_OLD_BACKUP_UNITS = {
-                DAY: _('Day(s)'),
-                WEEK: _('Week(s)'),
-                YEAR: _('Year(s)')
-                }
-
-    REPEATEDLY_UNITS = {
-                HOUR: _('Hour(s)'),
-                DAY: _('Day(s)'),
-                WEEK: _('Week(s)'),
-                MONTH: _('Month(s)')
-                }
-
-    MIN_FREE_SPACE_UNITS = {
-        DISK_UNIT_MB: 'MiB',
-        DISK_UNIT_GB : 'GiB'
-    }
-
-    DEFAULT_EXCLUDE = [ '.gvfs', '.cache/*', '.thumbnails*',
-    '.local/share/[Tt]rash*', '*.backup*', '*~', '.dropbox*', '/proc/*',
-    '/sys/*', '/dev/*', '/run/*', '/etc/mtab', '/var/cache/apt/archives/*.deb',
-    'lost+found/*', '/tmp/*', '/var/tmp/*', '/var/backups/*', '.Private' ]
+    # Used when new snapshot profile is created.
+    DEFAULT_EXCLUDE = [
+        '.gvfs',
+        '.cache/*',
+        '.thumbnails*',
+        '.local/share/[Tt]rash*',
+        '*.backup*',
+        '*~',
+        '.dropbox*',
+        '/proc/*',
+        '/sys/*',
+        '/dev/*',
+        '/run/*',
+        '/etc/mtab',
+        '/var/cache/apt/archives/*.deb',
+        'lost+found/*',
+        '/tmp/*',
+        '/var/tmp/*',
+        '/var/backups/*',
+        '.Private',
+        '/swapfile',
+        # Discord files
+        # See also: https://github.com/bit-team/backintime/issues/1555#issuecomment-1787230708
+        'SingletonLock',
+        'SingletonCookie',
+        # Mozilla files
+        # See also: https://github.com/bit-team/backintime/issues/1555#issuecomment-1787111063
+        'lock'
+    ]
 
     DEFAULT_RUN_NICE_FROM_CRON = True
     DEFAULT_RUN_NICE_ON_REMOTE = False
@@ -145,33 +136,13 @@ class Config(configfile.ConfigFileWithProfiles):
     DEFAULT_REDIRECT_STDOUT_IN_CRON = True
     DEFAULT_REDIRECT_STDERR_IN_CRON = False
 
-    exp = _(' EXPERIMENTAL!')
-    SNAPSHOT_MODES = {
-                #mode           : (<mounttools>,            'ComboBox Text',        need_pw|lbl_pw_1,       need_2_pw|lbl_pw_2),
-                'local'         : (None,                    _('Local'),             False,                  False),
-                'ssh'           : (sshtools.SSH,            _('SSH'),               _('SSH private key'),   False),
-                'local_encfs'   : (encfstools.EncFS_mount,  _('Local encrypted'),   _('Encryption'),        False),
-                'ssh_encfs'     : (encfstools.EncFS_SSH,    _('SSH encrypted'),     _('SSH private key'),   _('Encryption'))
-                }
-
-    SSH_CIPHERS =  {'default': _('Default'),
-                    'aes128-ctr': _('AES128-CTR'),
-                    'aes192-ctr': _('AES192-CTR'),
-                    'aes256-ctr': _('AES256-CTR'),
-                    'arcfour256': _('ARCFOUR256'),
-                    'arcfour128': _('ARCFOUR128'),
-                    'aes128-cbc': _('AES128-CBC'),
-                    '3des-cbc':   _('3DES-CBC'),
-                    'blowfish-cbc': _('Blowfish-CBC'),
-                    'cast128-cbc': _('Cast128-CBC'),
-                    'aes192-cbc': _('AES192-CBC'),
-                    'aes256-cbc': _('AES256-CBC'),
-                    'arcfour': _('ARCFOUR') }
-
     ENCODE = encfstools.Bounce()
     PLUGIN_MANAGER = pluginmanager.PluginManager()
 
     def __init__(self, config_path=None, data_path=None):
+        # Note: The main profiles name here is translated using the systems
+        # current locale because the language code in the config file wasn't
+        # read yet.
         configfile.ConfigFileWithProfiles.__init__(self, _('Main profile'))
 
         self._APP_PATH = tools.backintimePath()
@@ -306,6 +277,58 @@ class Config(configfile.ConfigFileWithProfiles):
         self.inhibitCookie = None
         self.setupUdev = tools.SetupUdev()
 
+        language_used = tools.initiate_translation(self.language())
+
+        # Development note (2023-08 by buhtz):
+        # Not the best location for a variable like this.
+        self.language_used = language_used
+        """ISO-639 language code of the used language. See
+        `tools._determine_current_used_language_code()` for details."""
+
+        # Workaround
+        self.default_profile_name = _('Main profile')
+
+        self.SNAPSHOT_MODES = {
+                    # mode: (
+                    #     <mounttools>,
+                    #     'ComboBox Text',
+                    #     need_pw|lbl_pw_1,
+                    #     need_2_pw|lbl_pw_2
+                    # ),
+                    'local': (
+                        None, _('Local'), False, False),
+                    'ssh': (
+                        sshtools.SSH, 'SSH', _('SSH private key'), False),
+                    'local_encfs': (
+                        encfstools.EncFS_mount,
+                        '{} {}'.format(_('Local'), _('encrypted')),
+                        _('Encryption'),
+                        False
+                    ),
+                    'ssh_encfs': (
+                        encfstools.EncFS_SSH,
+                        _('SSH encrypted'),
+                        _('SSH private key'),
+                        _('Encryption')
+                    )
+        }
+
+        self.SSH_CIPHERS = {
+            'default': _('Default'),
+            'aes128-ctr': 'AES128-CTR',
+            'aes192-ctr': 'AES192-CTR',
+            'aes256-ctr': 'AES256-CTR',
+            'arcfour256': 'ARCFOUR256',
+            'arcfour128': 'ARCFOUR128',
+            'aes128-cbc': 'AES128-CBC',
+            '3des-cbc': '3DES-CBC',
+            'blowfish-cbc': 'Blowfish-CBC',
+            'cast128-cbc': 'Cast128-CBC',
+            'aes192-cbc': 'AES192-CBC',
+            'aes256-cbc': 'AES256-CBC',
+            'arcfour': 'ARCFOUR'
+        }
+
     def save(self):
         self.setIntValue('config.version', self.CONFIG_VERSION)
         return super(Config, self).save(self._LOCAL_CONFIG_PATH)
@@ -320,14 +343,25 @@ class Config(configfile.ConfigFileWithProfiles):
 
             #check snapshots path
             if not snapshots_path:
-                self.notifyError(_('Profile: "%s"') % profile_name + '\n' + _('Snapshots folder is not valid !'))
+                self.notifyError(
+                    '{}\n{}'.format(
+                        _('Profile: "{name}"').format(name=profile_name),
+                        _('Snapshots folder is not valid!')
+                    )
+                )
                 return False
 
             #check include
             include_list = self.include(profile_id)
 
             if not include_list:
-                self.notifyError(_('Profile: "%s"') % profile_name + '\n' + _('You must select at least one folder to backup !'))
+                self.notifyError(
+                    '{}\n{}'.format(
+                        _('Profile: "{name}"').format(name=profile_name),
+                        _('You must select at least one folder to back up!')
+                    )
+                )
+
                 return False
 
             snapshots_path2 = snapshots_path + '/'
@@ -338,12 +372,25 @@ class Config(configfile.ConfigFileWithProfiles):
 
                 path = item[0]
                 if path == snapshots_path:
-                    self.notifyError(_('Profile: "%s"') % profile_name + '\n' + _('You can\'t include backup folder !'))
+                    self.notifyError(
+                        '{}\n{}'.format(
+                            _('Profile: "{name}"').format(name=profile_name),
+                            _("Backup folder cannot be included.")
+                        )
+                    )
+
                     return False
 
                 if len(path) >= len(snapshots_path2):
                     if path[: len(snapshots_path2)] == snapshots_path2:
-                        self.notifyError(_('Profile: "%s"') %  self.currentProfile() + '\n' + _('You can\'t include a backup sub-folder !'))
+                        self.notifyError(
+                            '{}\n{}'.format(
+                                _('Profile: "{name}"').format(
+                                    name=profile_name),
+                                _("Backup sub-folder cannot be included.")
+                            )
+                        )
+
                         return False
         return True
 
@@ -398,24 +445,27 @@ class Config(configfile.ConfigFileWithProfiles):
             mode = self.snapshotsMode(profile_id)
 
         if not os.path.isdir(value):
-            self.notifyError(_('%s is not a folder !') % value)
+            self.notifyError(_('Invalid option. {path} is not a folder.').format(path=value))
             return False
 
-        #Initialize the snapshots folder
-        logger.debug("Check snapshot folder: %s" %value, self)
+        # Initialize the snapshots folder
+        logger.debug("Check snapshot folder: %s" % value, self)
 
         host, user, profile = self.hostUserProfile(profile_id)
 
         if not all((host, user, profile)):
-            self.notifyError(_('Host/User/Profile-ID must not be empty!'))
+            self.notifyError(_('Host/User/Profile-ID must not be empty.'))
             return False
 
         full_path = os.path.join(value, 'backintime', host, user, profile)
         if not os.path.isdir(full_path):
-            logger.debug("Create folder: %s" %full_path, self)
+            logger.debug("Create folder: %s" % full_path, self)
             tools.makeDirs(full_path)
+
             if not os.path.isdir(full_path):
-                self.notifyError(_('Can\'t write to: %s\nAre you sure you have write access ?' % value))
+                self.notifyError(_(
+                    "Can't write to: {path}\nAre you sure you have "
+                    "write access?").format(path=value))
                 return False
 
             for p in (os.path.join(value, 'backintime'),
@@ -423,33 +473,46 @@ class Config(configfile.ConfigFileWithProfiles):
                 try:
                     os.chmod(p, 0o777)
                 except PermissionError as e:
-                    msg = "Failed to change permissions world writeable for '{}': {}"
+                    msg = "Failed to set permissions world-writable for '{}': {}"
                     logger.warning(msg.format(p, str(e)), self)
 
-        #Test filesystem
+        # Test filesystem
         fs = tools.filesystem(full_path)
+
         if fs == 'vfat':
-            self.notifyError(_("Destination filesystem for '%(path)s' is formatted with FAT which doesn't support hard-links. "
-                                "Please use a native Linux filesystem.") %
-                              {'path': value})
+            self.notifyError(_(
+                "Destination filesystem for {path} is formatted with FAT "
+                "which doesn't support hard-links. "
+                "Please use a native Linux filesystem.")
+                .format(path=value))
+
             return False
+
         elif fs == 'cifs' and not self.copyLinks():
-            self.notifyError(_("Destination filsystem for '%(path)s' is a SMB mounted share. Please make sure "
-                                "the remote SMB server supports symlinks or activate '%(copyLinks)s' in '%(expertOptions)s'.") %
-                              {'path': value,
-                               'copyLinks': _('Copy links (dereference symbolic links)'),
-                               'expertOptions': _('Expert Options')})
+            self.notifyError(_(
+                'Destination filesystem for {path} is an SMB-mounted share. '
+                'Please make sure the remote SMB server supports symlinks or '
+                'activate {copyLinks} in {expertOptions}.')
+                .format(path=value,
+                        copyLinks=_('Copy links (dereference symbolic links)'),
+                        expertOptions=_('Expert Options')))
+
         elif fs == 'fuse.sshfs' and mode not in ('ssh', 'ssh_encfs'):
-            self.notifyError(_("Destination filesystem for '%(path)s is a sshfs mounted share. sshfs doesn't support hard-links. "
-                                "Please use mode 'SSH' instead.") %
-                              {'path': value})
+            self.notifyError(_(
+                "Destination filesystem for {path} is an sshfs-mounted share."
+                " sshfs doesn't support hard-links. "
+                "Please use mode 'SSH' instead.")
+                .format(path=value))
+
             return False
 
         #Test write access for the folder
         check_path = os.path.join(full_path, 'check')
         tools.makeDirs(check_path)
         if not os.path.isdir(check_path):
-            self.notifyError(_('Can\'t write to: %s\nAre you sure you have write access ?' % full_path))
+            self.notifyError(_(
+                "Can't write to: {path}\nAre you sure you have "
+                "write access?").format(path=full_path))
             return False
 
         os.rmdir(check_path)
@@ -484,6 +547,37 @@ class Config(configfile.ConfigFileWithProfiles):
         value = self.hashCollision() + 1
         self.setIntValue('global.hash_collision', value)
 
+    def language(self) -> str:
+        #?Language code (ISO 639) used to translate the user interface.
+        #?If empty the operating systems current local is used. If 'en' the
+        #?translation is not active and the original English source strings
+        #?are used. It is the same if the value is unknown.
+        return self.strValue('global.language', '')
+
+    def setLanguage(self, language: str):
+        self.setStrValue('global.language', language if language else '')
+
+    def manual_starts_countdown(self) -> int:
+        """Countdown value about how often the users started the Back In Time
+        GUI.
+
+        It is an internal variable not meant to be used or manipulated be the
+        users. At the end of the countown the
+        :py:class:`ApproachTranslatorDialog` is presented to the user.
+
+        """
+        return self.intValue('internal.manual_starts_countdown', 10)
+
+    def decrement_manual_starts_countdown(self):
+        """Counts down to -1.
+
+        See :py:func:`manual_starts_countdown()` for details.
+        """
+        val = self.manual_starts_countdown()
+
+        if val > -1:
+            self.setIntValue('internal.manual_starts_countdown', val - 1)
+
     # SSH
     def sshSnapshotsPath(self, profile_id = None):
         #?Snapshot path on remote host. If the path is relative (no leading '/')
@@ -575,7 +669,7 @@ class Config(configfile.ConfigFileWithProfiles):
         #?0 = unlimited;0, >700
         value = self.profileIntValue('snapshots.ssh.max_arg_length', 0, profile_id)
         if value and value < 700:
-            raise ValueError('SSH max arg length %s is to low to run commands' % value)
+            raise ValueError('SSH max arg length %s is too low to run commands' % value)
         return value
 
     def setSshMaxArgLength(self, value, profile_id = None):
@@ -1190,7 +1284,7 @@ class Config(configfile.ConfigFileWithProfiles):
         if '--old-args' in val:
             logger.warning(
                 'Found rsync flag "--old-args". That flag will be removed '
-                'from the options because it does conflict with '
+                'from the options because it conflicts with '
                 'the flag "-s" (also known as "--secluded-args" or '
                 '"--protected-args") which is used by Back In Time to force '
                 'the "new form of argument protection" in rsync.'
@@ -1461,7 +1555,12 @@ class Config(configfile.ConfigFileWithProfiles):
         else:
             return True
 
-    SYSTEM_ENTRY_MESSAGE = "#Back In Time system entry, this will be edited by the gui:"
+    SYSTEM_ENTRY_MESSAGE \
+        = "#Back In Time system entry, this will be edited by the gui:"
+    """The string is used in crontab file to mark entries as owned by Back
+    In Time. **WARNING**: Don't modify that string in code because it is used
+    as match target while parsing the crontab file.
+    """
 
     def setupCron(self):
         for f in self.anacrontabFiles():
@@ -1487,19 +1586,27 @@ class Config(configfile.ConfigFileWithProfiles):
             return False
 
         if not newCrontab == oldCrontab:
+
             if not tools.checkCommand('crontab'):
+
                 if self.scheduleMode() is self.NONE:
                     return True
+
                 else:
                     logger.error('crontab not found.', self)
-                    self.notifyError(_('Can\'t find crontab.\nAre you sure cron is installed ?\n'
-                                        'If not you should disable all automatic backups.'))
+                    self.notifyError(_(
+                        "Can't find crontab.\n"
+                        "Are you sure cron is installed?\n"
+                        "If not you should disable all automatic backups."))
                     return False
+
             if not tools.writeCrontab(newCrontab):
                 self.notifyError(_('Failed to write new crontab.'))
                 return False
+
         else:
             logger.debug("Crontab didn't change. Skip writing.")
+
         return True
 
     def removeOldCrontab(self, crontab):
@@ -1509,7 +1616,7 @@ class Config(configfile.ConfigFileWithProfiles):
         if not self.SYSTEM_ENTRY_MESSAGE in crontab:
             #Then the system entry message has not yet been used in this crontab
             #therefore we assume all entries are system entries and clear them all.
-            #This is the old behaviour
+            #This is the old behavior
             logger.debug("Clearing all Back In Time entries", self)
             return [x for x in crontab if not 'backintime' in x]
         else:
@@ -1542,16 +1649,17 @@ class Config(configfile.ConfigFileWithProfiles):
             # entries if there is no automatic entry.
             newCrontab.append(self.SYSTEM_ENTRY_MESSAGE)
             newCrontab.append("#Please don't delete these two lines, or all custom backintime "
-                              "entries are going to be deleted next time you call the gui options!")
+                              "entries will be deleted next time you call the gui options!")
         return newCrontab
 
     def cronLine(self, profile_id):
         cron_line = ''
         profile_name = self.profileName(profile_id)
         backup_mode = self.scheduleMode(profile_id)
-        logger.debug("Profile: %s | Automatic backup: %s"
-                     %(profile_name, self.SCHEDULE_MODES[backup_mode]),
-                     self)
+
+        logger.debug(
+            f"Profile: {profile_name} | Automatic backup: {backup_mode}",
+            self)
 
         if self.NONE == backup_mode:
             return cron_line
@@ -1590,22 +1698,29 @@ class Config(configfile.ConfigFileWithProfiles):
                 cron_line = '0 * * * * {cmd}'
         elif self.UDEV == backup_mode:
             if not self.setupUdev.isReady:
-                logger.error("Failed to install Udev rule for profile %s. "
-                             "DBus Service 'net.launchpad.backintime.serviceHelper' not available"
-                             %profile_id, self)
-                self.notifyError(_('Could not install Udev rule for profile %(profile_id)s. '
-                                     'DBus Service \'%(dbus_interface)s\' '
-                                     'wasn\'t available')
-                                    %{'profile_id': profile_id,
-                                      'dbus_interface': 'net.launchpad.backintime.serviceHelper'})
+                logger.error(
+                    "Failed to install Udev rule for profile %s. DBus "
+                    "Service 'net.launchpad.backintime.serviceHelper' not "
+                    "available" % profile_id, self)
+
+                self.notifyError(_(
+                    "Could not install Udev rule for profile {profile_id}. "
+                    "DBus Service '{dbus_interface}' wasn't available")
+                    .format(profile_id=profile_id,
+                            dbus_interface='net.launchpad.backintime.'
+                                           'serviceHelper'))
+
             mode = self.snapshotsMode(profile_id)
             if mode == 'local':
                 dest_path = self.snapshotsFullPath(profile_id)
             elif mode == 'local_encfs':
                 dest_path = self.localEncfsPath(profile_id)
             else:
-                logger.error('Schedule udev doesn\'t work with mode %s' %mode, self)
-                self.notifyError(_('Schedule udev doesn\'t work with mode %s') % mode)
+                logger.error(
+                    'Schedule udev doesn\'t work with mode %s' % mode, self)
+                self.notifyError(_(
+                    "Schedule udev doesn't work with mode {mode}")
+                    .format(mode=mode))
                 return False
             uuid = tools.uuidFromPath(dest_path)
             if uuid is None:
@@ -1613,8 +1728,10 @@ class Config(configfile.ConfigFileWithProfiles):
                 #?Devices uuid used to automatically set up udev rule if the drive is not connected.
                 uuid = self.profileStrValue('snapshots.path.uuid', '', profile_id)
                 if not uuid:
-                    logger.error('Couldn\'t find UUID for "%s"' %dest_path, self)
-                    self.notifyError(_('Couldn\'t find UUID for "%s"') % dest_path)
+                    logger.error(
+                        "Couldn't find UUID for \"{dest_path}\"", self)
+                    self.notifyError(_("Couldn't find UUID for {path}")
+                                     .format(path=f'"{dest_path}"'))
                     return False
             else:
                 #cache uuid in config
