@@ -1,5 +1,6 @@
 #    Back In Time
-#    Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
+#    Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, Richard Bailey, Germar
+#    Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -18,16 +19,13 @@
 import os
 import collections
 import re
-
-import gettext
 import logger
 
-_ = gettext.gettext
 
 class ConfigFile(object):
+    """Store options in a plain text file in form of: key=value
     """
-    Store options in a plain text file in form of: key=value
-    """
+
     def __init__(self):
         self.dict = {}
         self.errorHandler = None
@@ -90,20 +88,26 @@ class ConfigFile(object):
         """
         def numsort(key):
             """
-            Sort int in keys in nummeric order instead of alphabetical by adding
+            Sort int in keys in numeric order instead of alphabetical by adding
             leading zeros to int's
             """
             return re.sub(r'\d+', lambda m: m.group(0).zfill(6), key)
+
         try:
             with open(filename, 'wt') as f:
                 keys = list(self.dict.keys())
-                keys.sort(key = numsort)
+                keys.sort(key=numsort)
+
                 for key in keys:
                     f.write("%s=%s\n" % (key, self.dict[key]))
+
         except OSError as e:
-            logger.error('Failed to save config: %s' %str(e), self)
-            self.notifyError(_('Failed to save config: %s') %str(e))
+            logger.error('Failed to save config: %s' % str(e), self)
+            self.notifyError(
+                '{}: {}'.format(_('Failed to save config'), str(e)))
+
             return False
+
         return True
 
     def load(self, filename, **kwargs):
@@ -116,7 +120,7 @@ class ConfigFile(object):
         self.dict = {}
         self.append(filename, **kwargs)
 
-    def append(self, filename, maxsplit = 1):
+    def append(self, filename, maxsplit=1):
         """
         Load options from file and append them to current options.
 
@@ -128,17 +132,21 @@ class ConfigFile(object):
 
         if not os.path.isfile(filename):
             return
+
         try:
             with open(filename, 'rt') as f:
                 lines = f.readlines()
+
         except OSError as e:
-            logger.error('Failed to load config: %s' %str(e), self)
-            self.notifyError(_('Failed to load config: %s') %str(e))
+            logger.error('Failed to load config: %s' % str(e), self)
+            self.notifyError(
+                '{}: {}'.format(_('Failed to load config'), str(e)))
 
         for line in lines:
             items = line.strip('\n').split('=', maxsplit)
+
             if len(items) == 2:
-                self.dict[items[ 0 ] ] = items[ 1]
+                self.dict[items[0]] = items[1]
 
     def remapKey(self, old_key, new_key):
         """
@@ -149,9 +157,12 @@ class ConfigFile(object):
             new_key (str):  new key name
         """
         if old_key != new_key:
+
             if old_key in self.dict:
+
                 if new_key not in self.dict:
-                    self.dict[new_key ] = self.dict[ old_key]
+                    self.dict[new_key] = self.dict[old_key]
+
                 del self.dict[old_key]
 
     def remapKeyRegex(self, pattern, replace):
@@ -165,8 +176,10 @@ class ConfigFile(object):
                             to replace all matches of ``pattern``.
         """
         c = re.compile(pattern)
+
         for key in list(self.dict):
             newKey = c.sub(replace, key)
+
             if key != newKey:
                 self.remapKey(key, newKey)
 
@@ -187,7 +200,7 @@ class ConfigFile(object):
         Return a 'str' instance of key's value.
 
         Args:
-            key (str): Key identifing the value in the config file.
+            key (str): Key identifying the value in the config file.
             default (str): Default value if ``key`` is not present.
 
         Returns:
@@ -208,7 +221,7 @@ class ConfigFile(object):
         """
         self.dict[key] = value
 
-    def intValue(self, key, default = 0):
+    def intValue(self, key, default=0):
         """
         Return a 'int' instance of key's value.
 
@@ -222,7 +235,8 @@ class ConfigFile(object):
         """
         try:
             return int(self.dict[key])
-        except:
+
+        except Exception:
             return default
 
     def setIntValue(self, key, value):
@@ -235,7 +249,7 @@ class ConfigFile(object):
         """
         self.setStrValue(key, str(value))
 
-    def boolValue(self, key, default = False):
+    def boolValue(self, key, default=False):
         """
         Return a 'bool' instance of key's value.
 
@@ -249,10 +263,13 @@ class ConfigFile(object):
         """
         try:
             val = self.dict[key]
+
             if "1" == val or "TRUE" == val.upper():
                 return True
+
             return False
-        except:
+
+        except Exception:
             return default
 
     def setBoolValue(self, key, value):
@@ -268,7 +285,7 @@ class ConfigFile(object):
         else:
             self.setStrValue(key, 'false')
 
-    def listValue(self, key, type_key = 'str:value', default = []):
+    def listValue(self, key, type_key='str:value', default=[]):
         """
         Return a list of values
 
@@ -294,36 +311,55 @@ class ConfigFile(object):
         """
         def typeKeySplit(tk):
             t, k = '', ''
+
             if isinstance(tk, str):
-                t, k = tk.split(':', maxsplit = 1)
+                t, k = tk.split(':', maxsplit=1)
+
             return (t, k)
 
         def value(key, tk):
             t, k = typeKeySplit(tk)
-            if t in ('str', 'int', 'bool'):
-                func = getattr(self, '%sValue' %t)
-                return func('%s.%s' %(key, k))
-            raise TypeError('Invalid type_key: %s' %tk)
 
-        size = self.intValue('%s.size' %key, -1)
+            if t in ('str', 'int', 'bool'):
+                func = getattr(self, '%sValue' % t)
+
+                return func('%s.%s' % (key, k))
+
+            raise TypeError('Invalid type_key: %s' % tk)
+
+        size = self.intValue('%s.size' % key, -1)
+
         if size < 0:
             return default
 
         ret = []
+
         for i in range(1, size + 1):
+
             if isinstance(type_key, str):
-                if not self.hasKey('%s.%s.%s' %(key, i, typeKeySplit(type_key)[1])):
+
+                if not self.hasKey('%s.%s.%s' %
+                                   (key, i, typeKeySplit(type_key)[1])):
                     continue
-                ret.append(value('%s.%s' %(key, i), type_key))
+
+                ret.append(value('%s.%s' % (key, i), type_key))
+
             elif isinstance(type_key, tuple):
-                if not self.hasKey('%s.%s.%s' %(key, i, typeKeySplit(type_key[0])[1])):
+
+                if not self.hasKey('%s.%s.%s' %
+                                   (key, i, typeKeySplit(type_key[0])[1])):
                     continue
+
                 items = []
+
                 for tk in type_key:
-                    items.append(value('%s.%s' %(key, i), tk))
+                    items.append(value('%s.%s' % (key, i), tk))
+
                 ret.append(tuple(items))
+
             else:
-                raise TypeError('Invalid type_key: %s' %type_key)
+                raise TypeError('Invalid type_key: %s' % type_key)
+
         return ret
 
     def setListValue(self, key, type_key, value):
@@ -334,7 +370,8 @@ class ConfigFile(object):
 
         Args:
             key (str):      used base-key
-            type_key (str): pattern of 'value-type:value-name'. See examples below.
+            type_key (str): pattern of 'value-type:value-name'.
+                            See examples below.
             value (list):   that should be stored
 
         ``type_key`` pattern examples::
@@ -347,38 +384,51 @@ class ConfigFile(object):
         """
         def setValue(key, tk, v):
             t = ''
+
             if isinstance(tk, str):
-                t, k = tk.split(':', maxsplit = 1)
+                t, k = tk.split(':', maxsplit=1)
+
             if t in ('str', 'int', 'bool'):
-                func = getattr(self, 'set%sValue' %t.capitalize())
-                return func('%s.%s' %(key, k), v)
-            raise TypeError('Invalid type_key: %s' %tk)
+                func = getattr(self, 'set%sValue' % t.capitalize())
+
+                return func('%s.%s' % (key, k), v)
+
+            raise TypeError('Invalid type_key: %s' % tk)
 
         if not isinstance(value, (list, tuple)):
-            raise TypeError('value has wrong type: %s' %value)
+            raise TypeError('value has wrong type: %s' % value)
 
-        old_size = self.intValue('%s.size' %key, -1)
-        self.setIntValue('%s.size' %key, len(value))
+        old_size = self.intValue('%s.size' % key, -1)
+        self.setIntValue('%s.size' % key, len(value))
+
+        for i, v in enumerate(value, start=1):
 
-        for i, v in enumerate(value, start = 1):
             if isinstance(type_key, str):
-                setValue('%s.%s' %(key, i), type_key, v)
+                setValue('%s.%s' % (key, i), type_key, v)
+
             elif isinstance(type_key, tuple):
+
                 for iv, tk in enumerate(type_key):
+
                     if len(v) > iv:
-                        setValue('%s.%s' %(key, i), tk, v[iv])
+                        setValue('%s.%s' % (key, i), tk, v[iv])
                     else:
-                        self.removeKey('%s.%s.%s' %(key, i, tk.split(':')[1]))
+                        self.removeKey('%s.%s.%s' % (key, i, tk.split(':')[1]))
             else:
-                raise TypeError('Invalid type_key: %s' %type_key)
+                raise TypeError('Invalid type_key: %s' % type_key)
 
         if len(value) < old_size:
+
             for i in range(len(value) + 1, old_size + 1):
+
                 if isinstance(type_key, str):
-                    self.removeKey('%s.%s.%s' %(key, i, type_key.split(':')[1]))
+                    self.removeKey(
+                        '%s.%s.%s' % (key, i, type_key.split(':')[1]))
+
                 elif isinstance(type_key, tuple):
                     for tk in type_key:
-                        self.removeKey('%s.%s.%s' %(key, i, tk.split(':')[1]))
+                        self.removeKey(
+                            '%s.%s.%s' % (key, i, tk.split(':')[1]))
 
     def removeKey(self, key):
         """
@@ -410,6 +460,7 @@ class ConfigFile(object):
     def keys(self):
         return list(self.dict.keys())
 
+
 class ConfigFileWithProfiles(ConfigFile):
     """
     Store options in profiles as 'profileX.key=value'
@@ -417,11 +468,13 @@ class ConfigFileWithProfiles(ConfigFile):
     Args:
         default_profile_name (str): default name of the first profile.
     """
-    def __init__(self, default_profile_name = ''):
+
+    def __init__(self, default_profile_name=''):
         ConfigFile.__init__(self)
 
         self.default_profile_name = default_profile_name
         self.current_profile_id = '1'
+        self.setCurrentProfile(self.current_profile_id)
 
     def load(self, filename):
         """
@@ -444,7 +497,9 @@ class ConfigFileWithProfiles(ConfigFile):
 
         found = False
         profiles = self.profiles()
+
         for profile_id in profiles:
+
             if profile_id == self.current_profile_id:
                 found = True
                 break
@@ -460,8 +515,8 @@ class ConfigFileWithProfiles(ConfigFile):
                     rename_keys.append(key)
 
             for old_key in rename_keys:
-                new_key = 'profile1.' + old_key[10 : ]
-                self.dict[new_key ] = self.dict[ old_key]
+                new_key = 'profile1.' + old_key[10:]
+                self.dict[new_key] = self.dict[old_key]
                 del self.dict[old_key]
 
         if self.intValue('profiles.version') != 1:
@@ -485,6 +540,7 @@ class ConfigFileWithProfiles(ConfigFile):
             list:   all available profile IDs as strings
         """
         profiles_unsorted = self.profiles()
+
         if len(profiles_unsorted) <= 1:
             return profiles_unsorted
 
@@ -494,7 +550,8 @@ class ConfigFileWithProfiles(ConfigFile):
             profiles_dict[self.profileName(profile_id).upper()] = profile_id
 
         # sort the dictionary by key (the profile name)
-        profiles_sorted = collections.OrderedDict(sorted(profiles_dict.items()))
+        profiles_sorted = collections.OrderedDict(
+            sorted(profiles_dict.items()))
 
         # return the names as a list
         return list(profiles_sorted.values())
@@ -520,37 +577,41 @@ class ConfigFileWithProfiles(ConfigFile):
         """
         if isinstance(profile_id, int):
             profile_id = str(profile_id)
+
         profiles = self.profiles()
 
         for i in profiles:
+
             if i == profile_id:
+
+                profile_name = self.profileName(profile_id)
+
                 self.current_profile_id = profile_id
-                logger.debug('change current profile: %s=%s'
-                             % (profile_id, self.profileName(profile_id)),
-                             self)
-                logger.changeProfile(profile_id)
+                logger.changeProfile(profile_id, profile_name)
+                logger.debug(
+                    f'Change current profile: {profile_id}={profile_name}',
+                    self)
+
                 return True
 
         return False
 
     def setCurrentProfileByName(self, name):
         """
-        Change the current profile.
+        Change the current profile by a givin name.
 
         Args:
             name (str): valid profile name
 
         Returns:
-            bool:       ``True`` if successful
+            bool: ``True`` if successful
         """
-        profiles = self.profiles()
 
-        for profile_id in profiles:
+        # Find the profile_id to this name...
+        for profile_id in self.profiles():
             if self.profileName(profile_id) == name:
-                self.current_profile_id = profile_id
-                logger.debug('change current profile: %s' %name, self)
-                logger.changeProfile(profile_id)
-                return True
+                # ...and set current profile by this id.
+                return self.setCurrentProfile(profile_id)
 
         return False
 
@@ -566,6 +627,7 @@ class ConfigFileWithProfiles(ConfigFile):
         """
         if isinstance(profile_id, int):
             profile_id = str(profile_id)
+
         return profile_id in self.profiles()
 
     def profileExistsByName(self, name):
@@ -581,12 +643,13 @@ class ConfigFileWithProfiles(ConfigFile):
         profiles = self.profiles()
 
         for profile_id in profiles:
+
             if self.profileName(profile_id) == name:
                 return True
 
         return False
 
-    def profileName(self, profile_id = None):
+    def profileName(self, profile_id=None):
         """
         Name of the profile.
 
@@ -598,12 +661,15 @@ class ConfigFileWithProfiles(ConfigFile):
         """
         if isinstance(profile_id, int):
             profile_id = str(profile_id)
+
         if profile_id is None:
             profile_id = self.current_profile_id
+
         if profile_id == '1':
             default = self.default_profile_name
         else:
             default = 'Profile %s' % profile_id
+
         return self.profileStrValue('name', default, profile_id)
 
     def addProfile(self, name):
@@ -619,11 +685,15 @@ class ConfigFileWithProfiles(ConfigFile):
         profiles = self.profiles()
 
         for profile_id in profiles:
+
             if self.profileName(profile_id) == name:
-                self.notifyError(_('Profile "%s" already exists !') % name)
+                self.notifyError(_(
+                    'Profile "{name}" already exists.').format(name=name))
+
                 return None
 
         new_id = 1
+
         while True:
             ok = True
 
@@ -641,9 +711,10 @@ class ConfigFileWithProfiles(ConfigFile):
         self.setStrValue('profiles', ':'.join(profiles))
 
         self.setProfileStrValue('name', name, new_id)
+
         return new_id
 
-    def removeProfile(self, profile_id = None):
+    def removeProfile(self, profile_id=None):
         """
         Remove profile and all its keys and values.
 
@@ -655,23 +726,32 @@ class ConfigFileWithProfiles(ConfigFile):
         """
         if isinstance(profile_id, int):
             profile_id = str(profile_id)
-        if profile_id == None:
+
+        if profile_id is None:
             profile_id = self.current_profile_id
 
         profiles = self.profiles()
+
         if len(profiles) <= 1:
-            self.notifyError(_('You can\'t remove the last profile !'))
+            self.notifyError(_("The last profile cannot be removed."))
+
             return False
 
         found = False
         index = 0
+
         for profile in profiles:
+
             if profile == profile_id:
                 self.removeKeysStartsWith(self.profileKey('', profile_id))
+
                 del profiles[index]
+
                 self.setStrValue('profiles', ':'.join(profiles))
                 found = True
+
                 break
+
             index = index + 1
 
         if not found:
@@ -682,7 +762,7 @@ class ConfigFileWithProfiles(ConfigFile):
 
         return True
 
-    def setProfileName(self, name, profile_id = None):
+    def setProfileName(self, name, profile_id=None):
         """
         Change the name of the profile.
 
@@ -695,18 +775,24 @@ class ConfigFileWithProfiles(ConfigFile):
         """
         if isinstance(profile_id, int):
             profile_id = str(profile_id)
-        if profile_id == None:
+
+        if profile_id is None:
             profile_id = self.current_profile_id
 
         profiles = self.profiles()
 
         for profile in profiles:
+
             if self.profileName(profile) == name:
+
                 if profile[0] != profile_id:
-                    self.notifyError(_('Profile "%s" already exists !') % name)
+                    self.notifyError(_(
+                        'Profile "{name}" already exists.').format(name=name))
+
                     return False
 
         self.setProfileStrValue('name', name, profile_id)
+
         return True
 
     def profileKey(self, key, profile_id=None):
@@ -728,7 +814,7 @@ class ConfigFileWithProfiles(ConfigFile):
 
         return 'profile' + profile_id + '.' + key
 
-    def removeProfileKey(self, key, profile_id = None):
+    def removeProfileKey(self, key, profile_id=None):
         """
         Remove the key from profile.
 
@@ -738,7 +824,7 @@ class ConfigFileWithProfiles(ConfigFile):
         """
         self.removeKey(self.profileKey(key, profile_id))
 
-    def removeProfileKeysStartsWith(self, prefix, profile_id = None):
+    def removeProfileKeysStartsWith(self, prefix, profile_id=None):
         """
         Remove the keys starting with prefix from profile.
 
@@ -749,7 +835,7 @@ class ConfigFileWithProfiles(ConfigFile):
         """
         self.removeKeysStartsWith(self.profileKey(prefix, profile_id))
 
-    def remapProfileKey(self, oldKey, newKey, profileId = None):
+    def remapProfileKey(self, oldKey, newKey, profileId=None):
         """
         Remap profile keys to a new key name.
 
@@ -761,7 +847,7 @@ class ConfigFileWithProfiles(ConfigFile):
         self.remapKey(self.profileKey(oldKey, profileId),
                       self.profileKey(newKey, profileId))
 
-    def hasProfileKey(self, key, profile_id = None):
+    def hasProfileKey(self, key, profile_id=None):
         """
         ``True`` if key is set in profile.
 
@@ -782,23 +868,28 @@ class ConfigFileWithProfiles(ConfigFile):
         """
         return self.strValue(self.profileKey(key, profile_id), default)
 
-    def setProfileStrValue(self, key, value, profile_id = None):
+    def setProfileStrValue(self, key, value, profile_id=None):
         self.setStrValue(self.profileKey(key, profile_id), value)
 
-    def profileIntValue(self, key, default = 0, profile_id = None):
+    def profileIntValue(self, key, default=0, profile_id=None):
         return self.intValue(self.profileKey(key, profile_id), default)
 
-    def setProfileIntValue(self, key, value, profile_id = None):
+    def setProfileIntValue(self, key, value, profile_id=None):
         self.setIntValue(self.profileKey(key, profile_id), value)
 
-    def profileBoolValue(self, key, default = False, profile_id = None):
+    def profileBoolValue(self, key, default=False, profile_id=None):
         return self.boolValue(self.profileKey(key, profile_id), default)
 
-    def setProfileBoolValue(self, key, value, profile_id = None):
+    def setProfileBoolValue(self, key, value, profile_id=None):
         self.setBoolValue(self.profileKey(key, profile_id), value)
 
-    def profileListValue(self, key, type_key = 'str:value', default = [], profile_id = None):
-        return self.listValue(self.profileKey(key, profile_id), type_key, default)
+    def profileListValue(self,
+                         key,
+                         type_key='str:value',
+                         default=[],
+                         profile_id=None):
+        return self.listValue(
+            self.profileKey(key, profile_id), type_key, default)
 
-    def setProfileListValue(self, key, type_key, value, profile_id = None):
+    def setProfileListValue(self, key, type_key, value, profile_id=None):
         self.setListValue(self.profileKey(key, profile_id), type_key, value)
