@@ -13,11 +13,100 @@
 #    You should have received a copy of the GNU General Public License along
 #    with this program; if not, write to the Free Software Foundation, Inc.,
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+"""The mount API.
 
+    The high-level mount API is :py:class:`Mount` and handles mount,
+    umount, remount and checks for *Back In Time*. The low-level mount API
+    is :py:class:`MountControl`. The latter can be used to create own
+    mounting services via subclassing it. See the following example.
+
+    Example:
+
+        See this template to create your own mounting service by inheriting
+        from :py:class:`MountControl`. All you need to do is:
+
+        - Add your settings in ``qt/settingsdialog.py``.
+        - Add settings in ``common/config.py``.
+        - Use the following template class ``MountDummy``, rename and modify
+          it to your needs.
+        - Please use ``self.currentMountpoint`` as your local mountpoint.
+        - Your class should inherit from :py:class:`mount.MountControl`.
+
+        As real usage example see the two classes :py:class:`sshtools.SSH` and
+        :py:class:`encfstools.EncFS_mount`.
+
+    This is the template: ::
+
+        class MountDummy(mount.MountControl):
+            def __init__(self, *args, **kwargs):
+                super(MountDummy, self).__init__(*args, **kwargs)
+
+                self.all_kwargs = {}
+
+                # First we need to map the settings.
+                # If <arg> is in kwargs (e.g. if this class is called with
+                # dummytools.Dummy(<arg> = <value>) this will map self.<arg> to
+                # kwargs[<arg>]; else self.<arg> = <default> from config
+                # e.g. self.setattrKwargs(<arg>, <default>, **kwargs)
+                self.setattrKwargs(
+                    'user', self.config.get_dummy_user(self.profile_id), **kwargs)
+                self.setattrKwargs(
+                    'host', self.config.get_dummy_host(self.profile_id), **kwargs)
+                self.setattrKwargs(
+                    'port', self.config.get_dummy_port(self.profile_id), **kwargs)
+                self.setattrKwargs(
+                    'password',
+                    self.config.password(self.parent, self.profile_id),
+                    store = False, **kwargs)
+
+                self.setDefaultArgs()
+
+                # If self.currentMountpoint is not the remote snapshot path
+                # you can specify a subfolder of self.currentMountpoint for
+                # the symlink
+                self.symlink_subfolder = None
+
+                self.mountproc = 'dummy'
+                self.log_command = '%s: %s@%s' % (self.mode, self.user, self.host)
+
+            def _mount(self):
+                # Mount the service
+                # Implement your mountprocess here.
+                pass
+
+            def _umount(self):
+                # Umount the service
+                # Implement your unmountprocess here.
+                pass
+
+            def preMountCheck(self, first_run = False):
+                # Check what ever conditions must be given for the mount to be
+                # done successful.
+                # Raise MountException('Error description') if service can not mount
+                # return True if everything is okay
+                # all pre|post_[u]mount_check can also be used to prepare
+                # things or clean up
+                return True
+
+            def postMountCheck(self):
+                # Check if mount was successful
+                # Raise MountException('Error description') if not
+                return True
+
+            def preUmountCheck(self):
+                # Check if service is safe to umount
+                # Raise MountException('Error description') if not
+                return True
+
+            def postUmountCheck(self):
+                # Check if umount successful
+                # Raise MountException('Error description') if not
+                return True
+
+"""
 import os
 import subprocess
 import json
-import gettext
 from zlib import crc32
 from time import sleep
 
@@ -27,7 +116,6 @@ import tools
 import password
 from exceptions import MountException, HashCollision
 
-_=gettext.gettext
 
 class Mount(object):
     """
@@ -293,27 +381,30 @@ class Mount(object):
             return self.mount(mode = mode, **kwargs)
 
 class MountControl(object):
-    """
-    This is the low-level mount API. This should be subclassed by backends.
+    """This is the low-level mount API. This should be subclassed by backends.
 
     Subclasses should have its own ``__init__`` but **must** also call the
-    inherited ``__init__``.
+    inherited ``__init__``. See module description (:py:mod:`mount`) for
+    a detailed example.
 
-    You **must** overwrite methods:\n
-        :py:func:`MountControl._mount`
+    You **must** overwrite methods:
 
-    You **can** overwrite methods:\n
-        :py:func:`MountControl._umount`\n
-        :py:func:`MountControl.preMountCheck`\n
-        :py:func:`MountControl.postMountCheck`\n
-        :py:func:`MountControl.preUmountCheck`\n
-        :py:func:`MountControl.postUmountCheck`
+    - :py:func:`MountControl._mount`
 
-    These arguments **must** be defined in ``self`` namespace by
-    subclassing ``__init__`` method:\n
-        mountproc (str):        process used to mount\n
-        log_command (str):      shortened form of mount command used in logs\n
-        symlink_subfolder (str):mountpoint-subfolder which should be linked\n
+    You **can** overwrite methods:
+
+    - :py:func:`MountControl._umount`
+    - :py:func:`MountControl.preMountCheck`
+    - :py:func:`MountControl.postMountCheck`
+    - :py:func:`MountControl.preUmountCheck`
+    - :py:func:`MountControl.postUmountCheck`
+
+    These arguments (all of type :py:obj:`str`) **must** be defined in
+    ``self`` namespace by subclassing ``__init__`` method:
+
+    - ``mountproc``: process used to mount
+    - ``log_command``: shortened form of mount command used in logs
+    - ``symlink_subfolder``: mountpoint-subfolder which should be linked
 
     Args:
         cfg (config.Config):    current config
@@ -329,8 +420,6 @@ class MountControl(object):
                                 mountpoints
     """
 
-    CHECK_FUSE_GROUP = False
-
     def __init__(self,
                  cfg = None,
                  profile_id = None,
@@ -340,6 +429,13 @@ class MountControl(object):
                  symlink = True,
                  *args,
                  **kwargs):
+        # The following members should get valid values from the inheriting
+        # class.
+        self.mode = None
+        self.log_command = None
+        self.mountproc = None
+        self.symlink_subfolder = None
+
         self.config = cfg
         if self.config is None:
             self.config = config.Config()
@@ -368,7 +464,7 @@ class MountControl(object):
         ``self.all_kwargs`` need to be filled through :py:func:`setattrKwargs`
         before calling this.
         """
-        #self.destination should contain all arguments that are nessesary for
+        #self.destination should contain all arguments that are necessary for
         #mount.
         args = list(self.all_kwargs.keys())
         self.destination = '%s:' % self.all_kwargs['mode']
@@ -377,16 +473,17 @@ class MountControl(object):
         for arg in args:
             self.destination += ' %s' % self.all_kwargs[arg]
 
-        #unique id for every different mount settings. Similar settings even in
-        #different profiles will generate the same hash_id and so share the same
-        #mountpoint
+        # Unique id for every different mount settings. Similar settings even
+        # in different profiles will generate the same hash_id and so share
+        # the same mountpoint.
         if self.hash_id is None:
             self.hash_id = self.hash(self.destination)
 
         self.mount_root = self.config._LOCAL_MOUNT_ROOT
-        self.snapshots_path = self.config.snapshotsPath(profile_id = self.profile_id,
-                                                             mode = self.mode,
-                                                             tmp_mount = self.tmp_mount)
+        self.snapshots_path = self.config.snapshotsPath(
+            profile_id = self.profile_id,
+            mode = self.mode,
+            tmp_mount = self.tmp_mount)
 
         self.hash_id_path = self.hashIdPath()
         self.currentMountpoint = self.mountpoint()
@@ -395,7 +492,7 @@ class MountControl(object):
 
     def mount(self, check = True):
         """
-        Low-level `mount`. Set mountprocess lock and prepair mount, run checks
+        Low-level `mount`. Set mountprocess lock and prepare mount, run checks
         and than call :py:func:`_mount` for the subclassed backend. Finally set
         mount lock and symlink and release mountprocess lock.
 
@@ -415,22 +512,33 @@ class MountControl(object):
         """
         self.createMountStructure()
         self.mountProcessLockAcquire()
+
         try:
             if self.mounted():
+
                 if not self.compareUmountInfo():
                     #We probably have a hash collision
                     self.config.incrementHashCollision()
-                    raise HashCollision(_('Hash collision occurred in hash_id %s. Incrementing global value hash_collision and try again.') % self.hash_id)
-                logger.info('Mountpoint %s is already mounted' %self.currentMountpoint, self)
+                    raise HashCollision(
+                        f'Hash collision occurred in hash_id {self.hash_id}. '
+                        'Incrementing global value hash_collision and '
+                        'trying again.')
+
+                logger.info('Mountpoint {} is already mounted'
+                            .format(self.currentMountpoint),
+                            self)
             else:
                 if check:
                     self.preMountCheck()
+
                 self._mount()
                 self.postMountCheck()
+
                 logger.info('mount %s on %s'
                             %(self.log_command, self.currentMountpoint),
                             self)
                 self.writeUmountInfo()
+
         except Exception:
             raise
         else:
@@ -455,10 +563,10 @@ class MountControl(object):
                 logger.info('Mountpoint %s does not exist.' % self.currentMountpoint, self)
             else:
                 if not self.mounted():
-                    logger.info('Mountpoint %s is not mounted' % self.currentMountpoint, self)
+                    logger.info('Mountpoint %s is not mounted.' % self.currentMountpoint, self)
                 else:
                     if self.mountLockCheck():
-                        logger.info('Mountpoint %s still in use. Keep mounted' % self.currentMountpoint, self)
+                        logger.info('Mountpoint %s still in use. Keep mounted.' % self.currentMountpoint, self)
                     else:
                         self.preUmountCheck()
                         self._umount()
@@ -490,16 +598,18 @@ class MountControl(object):
         overwritten by backends which subclasses :py:class:`MountControl`.
 
         Raises:
-            exceptions.MountException:  if unmount failed
+            exceptions.MountException: If unmount failed.
         """
         try:
             subprocess.check_call(['fusermount', '-u', self.currentMountpoint])
-        except subprocess.CalledProcessError:
-            raise MountException(_('Can\'t unmount %(proc)s from %(mountpoint)s')
-                                  %{'proc': self.mountproc,
-                                    'mountpoint': self.currentMountpoint})
 
-    def preMountCheck(self, first_run = False):
+        except subprocess.CalledProcessError:
+            raise MountException(
+                _("Can't unmount {mountprocess} from {mountpoint}.")
+                .format(mountprocess=self.mountproc,
+                        mountpoint=self.currentMountpoint))
+
+    def preMountCheck(self, first_run=False):
         """
         Check what ever conditions must be given for the mount to be done
         successful. This **can** be overwritten in backends which
@@ -572,34 +682,19 @@ class MountControl(object):
 
     def checkFuse(self):
         """
-        Check if command in self.mountproc is installed and user is part of
-        group ``fuse``.
+        Check if command in ``self.mountproc`` is installed.
 
         Raises:
-            exceptions.MountException:  if either command is not available or
-                                        user is not in group fuse
+            exceptions.MountException: If either command is not available.
         """
-        logger.debug('Check fuse', self)
+
         if not tools.checkCommand(self.mountproc):
-            logger.debug('%s is missing' %self.mountproc, self)
-            raise MountException(_('%(proc)s not found. Please install e.g. %(install_command)s')
-                                  %{'proc': self.mountproc,
-                                    'install_command': "'apt-get install %s'" %self.mountproc})
-        if self.CHECK_FUSE_GROUP:
-            user = self.config.user()
-            try:
-                fuse_grp_members = grp.getgrnam('fuse')[3]
-            except KeyError:
-                #group fuse doesn't exist. So most likely it isn't used by this distribution
-                logger.debug("Group fuse doesn't exist. Skip test", self)
-                return
-            if not user in fuse_grp_members:
-                logger.debug('User %s is not in group fuse' %user, self)
-                raise MountException(_('%(user)s is not member of group \'fuse\'.\n '
-                                        'Run \'sudo adduser %(user)s fuse\'. To apply '
-                                        'changes logout and login again.\nLook at '
-                                        '\'man backintime\' for further instructions.')
-                                        % {'user': user})
+            logger.debug(f'{self.mountproc} is missing', self)
+
+            raise MountException(
+                _('{} not found. Please install e.g. {}')
+                .format(self.mountproc,
+                        f"'apt-get install {self.mountproc}'"))
 
     def mounted(self):
         """
@@ -614,19 +709,24 @@ class MountControl(object):
         """
         if os.path.ismount(self.currentMountpoint):
             return True
+
         else:
             try:
                 if os.listdir(self.currentMountpoint):
-                    raise MountException(_('mountpoint %s not empty.') % self.currentMountpoint)
+                    raise MountException(_('Mountpoint {} not empty.')
+                                         .format(self.currentMountpoint))
+
             except FileNotFoundError:
                 pass
+
             return False
 
     def createMountStructure(self):
         """
         Create folders that are necessary for mounting.
 
-        Folder structure in ~/.local/share/backintime/mnt/ (self.mount_root)::
+        Folder structure in ``~/.local/share/backintime/mnt/``
+        (``self.mount_root``)::
 
             .
             ├── <pid>.lock              <=  mountprocess lock that will prevent
@@ -641,7 +741,7 @@ class MountControl(object):
             │   │                           mountpoint
             │   │
             │   ├── umount              <=  ``self.umount_info`` json file with
-            │   │                           all nessesary args for unmount
+            │   │                           all necessary args for unmount
             │   │
             │   └── locks/              <=  ``self.lock_path`` for each process
             │                               you have a ``<pid>.lock`` file
@@ -680,11 +780,10 @@ class MountControl(object):
         while self.checkLocks(lock_path, lockSuffix):
             count += 1
             if count == timeout:
-                raise MountException(_('Mountprocess lock timeout'))
+                raise MountException('Mountprocess lock timeout')
             sleep(1)
 
-        logger.debug('Acquire mountprocess lock %s'
-                     %lock, self)
+        logger.debug(f'Acquire mountprocess lock {lock}', self)
         with open(lock, 'w') as f:
             f.write(self.pid)
 
@@ -695,8 +794,7 @@ class MountControl(object):
         lock_path = self.mount_root
         lockSuffix = '.lock'
         lock = os.path.join(lock_path, self.pid + lockSuffix)
-        logger.debug('Release mountprocess lock %s'
-                     %lock, self)
+        logger.debug(f'Release mountprocess lock {lock}', self)
         if os.path.exists(lock):
             os.remove(lock)
 
