@@ -17,12 +17,13 @@
 
 """This module offers some helpers and tools for unittesting.
 
-Most of the conent are `unittest.TestCase` derived classed doing basic setup
+Most of the content are `unittest.TestCase` derived classed doing basic setup
 for the testing environment. They are dealing with snapshot path's, SSH,
 config files and things like set.
 """
 
 import os
+import pathlib
 import sys
 import unittest
 import socket
@@ -32,26 +33,26 @@ from contextlib import contextmanager
 
 sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
 import logger
+import tools
+# Needed because backintime.startApp() is not invoked.
+tools.initiate_translation(None)
 import config
 import snapshots
-import tools
 
 # mock notifyplugin to suppress notifications
 tools.registerBackintimePath('qt', 'plugins')
 
 TMP_FLOCK = NamedTemporaryFile(prefix='backintime', suffix='.flock')
-PRIV_KEY_FILE = os.path.expanduser(
-    os.path.join("~", ".ssh", "id_rsa"))
-AUTHORIZED_KEYS_FILE = os.path.expanduser(
-    os.path.join("~", ".ssh", "authorized_keys"))
+# A simple (local) RSA key pair via "ssh-keygen" and activate it
+# via "ssh-copy-id localhost".
+PRIV_KEY_FILE = pathlib.Path.home() / '.ssh' / 'id_rsa'
+PUBLIC_KEY_FILE = PRIV_KEY_FILE.with_suffix('.pub')
+AUTHORIZED_KEYS_FILE = pathlib.Path.home() / '.ssh' / 'authorized_keys'
 DUMMY = 'dummy_test_process.sh'
 
-if os.path.exists(PRIV_KEY_FILE + '.pub') \
-   and os.path.exists(AUTHORIZED_KEYS_FILE):
-
-    with open(PRIV_KEY_FILE + '.pub', 'rb') as pub:
-
-        with open(AUTHORIZED_KEYS_FILE, 'rb') as auth:
+if all([PUBLIC_KEY_FILE.exists(), AUTHORIZED_KEYS_FILE.exists()]):
+    with PUBLIC_KEY_FILE.open('rb') as pub:
+        with AUTHORIZED_KEYS_FILE.open('rb') as auth:
             KEY_IN_AUTH = pub.read() in auth.readlines()
 else:
     KEY_IN_AUTH = False
@@ -66,20 +67,30 @@ except ConnectionRefusedError:
 
 SKIP_SSH_TEST_MESSAGE = 'Skip as this test requires a local ssh server, ' \
                         'public and private keys installed'
-LOCAL_SSH = all((tools.processExists('sshd'),
-                 os.path.isfile(PRIV_KEY_FILE),
-                 KEY_IN_AUTH,
-                 sshdPortAvailable))
+LOCAL_SSH = all([
+    # Server process running?
+    tools.processExists('sshd'),
+    # Privat keyfile (id_rsa)
+    PRIV_KEY_FILE.is_file(),
+    # Key known (copied via "ssh-copy-id")
+    KEY_IN_AUTH,
+    # SSH port (22) available at the server
+    sshdPortAvailable
+])
 
 ON_TRAVIS = os.environ.get('TRAVIS', 'None').lower() == 'true'
 ON_RTD = os.environ.get('READTHEDOCS', 'None').lower() == 'true'
 
-
+# Temporary workaround (buhtz: 2023-09)
+# Not all components of the code are able to handle Path objects
+PRIV_KEY_FILE = str(PRIV_KEY_FILE)
+PUBLIC_KEY_FILE = str(PUBLIC_KEY_FILE)
+AUTHORIZED_KEYS_FILE = str(AUTHORIZED_KEYS_FILE)
 
 class TestCase(unittest.TestCase):
     """Base class for Back In Time unit- and integration testing.
 
-    In summary folling is set via 'setUp()' and '__init__()':
+    In summary following is set via 'setUp()' and '__init__()':
        - Initialize logging.
        - Set path to config file (not open it).
        - Set path the "backup source" directory.
@@ -91,7 +102,7 @@ class TestCase(unittest.TestCase):
         The config file in the "test" folder is used.
 
         Args:
-            methodName: Unkown.
+            methodName: Unknown.
         """
 
         # note by buhtz: This is not recommended. Unittest module handle
@@ -125,7 +136,7 @@ class TestCase(unittest.TestCase):
         """
         """
         # BUHTZ 10/09/2022: In my understanding it is not needed and would be
-        # done implicite when the test class is destroyed.
+        # done implicitly when the test class is destroyed.
         self.sharePathObj.cleanup()
 
     def callback(self, func, *args):
