@@ -1,5 +1,6 @@
 #    Back In Time
-#    Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze, Taylor Raack
+#    Copyright (C) 2008-2022 Oprea Dan, Bart de Koning, Richard Bailey,
+#    Germar Reitze, Taylor Raack
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -14,8 +15,6 @@
 #    You should have received a copy of the GNU General Public License along
 #    with this program; if not, write to the Free Software Foundation, Inc.,
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-
-
 import os
 import sys
 import pathlib
@@ -26,6 +25,7 @@ import re
 import errno
 import gzip
 import tempfile
+import gettext
 try:
     from collections.abc import MutableSet
 except ImportError:
@@ -36,16 +36,30 @@ import atexit
 from datetime import datetime
 from packaging.version import Version
 from time import sleep
-keyring = None
-keyring_warn = False
+
+import logger
+
+# Try to import keyring
+is_keyring_available = False
 try:
+    # Jan 4, 2024 aryoda: The env var BIT_USE_KEYRING is neither documented
+    #                     anywhere nor used at all in the code.
+    #                     Via "git blame" I have found a commit message saying:
+    #                     "block subsequent 'import keyring' if it failed once"
+    #                     So I assume it is an internal temporary env var only.
+    # Note: os.geteuid() is used instead of tools.isRoot() here
+    #       because the latter is still not available here in the global
+    #       module code.
     if os.getenv('BIT_USE_KEYRING', 'true') == 'true' and os.geteuid() != 0:
         import keyring
         from keyring import backend
-except:
-    keyring = None
+        import keyring.util.platform_
+        is_keyring_available = True
+except Exception as e:
+    is_keyring_available = False
+    # block subsequent 'import keyring' if it failed once before
     os.putenv('BIT_USE_KEYRING', 'false')
-    keyring_warn = True
+    logger.warning(f"'import keyring' failed with: {repr(e)}")
 
 # getting dbus imports to work in Travis CI is a huge pain
 # use conditional dbus import
@@ -56,24 +70,28 @@ try:
     import dbus
 except ImportError:
     if ON_TRAVIS or ON_RTD:
-        #python-dbus doesn't work on Travis yet.
+        # python-dbus doesn't work on Travis yet.
         dbus = None
     else:
         raise
 
 import configfile
-import logger
 import bcolors
 from applicationinstance import ApplicationInstance
 from exceptions import Timeout, InvalidChar, InvalidCmd, LimitExceeded, PermissionDeniedByPolicy
+import languages
 
 DISK_BY_UUID = '/dev/disk/by-uuid'
 
-def sharePath():
-    """
-    Get BackInTimes installation base path.
+# |-----------------|
+# | Handling paths  |
+# |-----------------|
 
-    If running from source return default '/usr/share'
+
+def sharePath():
+    """Get path where Back In Time is installed.
+
+    If running from source return default ``/usr/share``.
 
     Returns:
         str:    share path like::
@@ -82,11 +100,201 @@ def sharePath():
                     /usr/local/share
                     /opt/usr/share
     """
-    share = os.path.abspath(os.path.join(__file__, os.pardir, os.pardir, os.pardir))
+    share = os.path.abspath(
+        os.path.join(__file__, os.pardir, os.pardir, os.pardir)
+    )
+
     if os.path.basename(share) == 'share':
         return share
+
+    return '/usr/share'
+
+
+# |---------------------------------------------------|
+# | Internationalization (i18n) & localization (L10n) |
+# |---------------------------------------------------|
+_GETTEXT_DOMAIN = 'backintime'
+_GETTEXT_LOCALE_DIR = pathlib.Path(sharePath()) / 'locale'
+
+
+def _determine_current_used_language_code(translation, language_code):
+    """Return the language code used by GNU gettext for real.
+
+    Args:
+        translation(gettext.NullTranslations): The translation installed.
+        language_code(str): Configured language code.
+
+    The used language code can differ from the one in Back In Times config
+    file and from the current systems locale.
+
+    It is necessary because of situations where the language is not explicit
+    setup in Back In Time config file and GNU gettext do try to find and use a
+    language file for the current systems locale. But even this can fail and
+    the fallback (source language "en") is used or an alternative locale.
+    """
+
+    try:
+        # The field "language" is rooted in header of the po-file.
+        current_used_language_code = translation.info()['language']
+
+    except KeyError:
+        # Workaround:
+        # BIT versions 1.3.3 or older don't have the "language" field in the
+        # header of their po-files.
+
+        # The approach is to extract the language code from the full filepath
+        # of the currently used mo-file.
+
+        # Get the filepath of the used mo-file
+        mo_file_path = gettext.find(
+            domain=_GETTEXT_DOMAIN,
+            localedir=_GETTEXT_LOCALE_DIR,
+            languages=[language_code, ] if language_code else None,
+        )
+
+        # Extract the language code form that path
+        if mo_file_path:
+            mo_file_path = pathlib.Path(mo_file_path)
+            # e.g /usr/share/locale/de/LC_MESSAGES/backintime.mo
+            #                       ^^
+            current_used_language_code = mo_file_path.relative_to(
+                _GETTEXT_LOCALE_DIR).parts[0]
+
+        else:
+            # Workaround: Happens when LC_ALL=C, which in BIT context mean
+            # its source language in English.
+            current_used_language_code = 'en'
+
+    return current_used_language_code
+
+
+def initiate_translation(language_code):
+    """Initiate Class-based API of GNU gettext.
+
+    Args:
+        language_code(str): Language code to use (based on ISO-639).
+
+    It installs the ``_()`` (and ``ngettext()`` for plural forms)  in the
+    ``builtins`` namespace and eliminates the need to ``import gettext``
+    and declare ``_()`` in each module. The systems current local is used
+    if the language code is None.
+    """
+
+    if language_code:
+        logger.debug(f'Language code "{language_code}".')
     else:
-        return '/usr/share'
+        logger.debug('No language code. Use systems current locale.')
+
+    translation = gettext.translation(
+        domain=_GETTEXT_DOMAIN,
+        localedir=_GETTEXT_LOCALE_DIR,
+        languages=[language_code, ] if language_code else None,
+        fallback=True
+    )
+    translation.install(names=['ngettext'])
+
+    return _determine_current_used_language_code(translation, language_code)
+
+
+def get_available_language_codes():
+    """Return language codes available in the current installation.
+
+    The filesystem is searched for ``backintime.mo`` files and the language
+    code is extracted from the full path of that files.
+
+    Return:
+        List of language codes.
+    """
+
+    # full path of one mo-file
+    # e.g. /usr/share/locale/de/LC_MESSAGES/backintime.mo
+    mo = gettext.find(domain=_GETTEXT_DOMAIN, localedir=_GETTEXT_LOCALE_DIR)
+
+    if mo:
+        mo = pathlib.Path(mo)
+    else:
+        # Workaround. This happens if LC_ALL=C and BIT don't use an explicit
+        # language. Should be re-design.
+        mo = _GETTEXT_LOCALE_DIR / 'xy' / 'LC_MESSAGES' / 'backintime.mo'
+
+    # e.g. de/LC_MESSAGES/backintime.mo
+    mo = mo.relative_to(_GETTEXT_LOCALE_DIR)
+
+    # e.g. */LC_MESSAGES/backintime.mo
+    mo = pathlib.Path('*') / pathlib.Path(*mo.parts[1:])
+
+    mofiles = _GETTEXT_LOCALE_DIR.rglob(str(mo))
+
+    return [p.relative_to(_GETTEXT_LOCALE_DIR).parts[0] for p in mofiles]
+
+
+def get_language_names(language_code):
+    """Return a list with language names in three different flavors.
+
+    Language codes from `get_available_language_codes()` are combined with
+    `languages.language_names` to prepare the list.
+
+    Args:
+        language_code (str): Usually the current language used by Back In Time.
+
+    Returns:
+        A dictionary indexed by language codes with 3-item tuples as
+        values. Each tuple contain three representations of the same language:
+        ``language_code`` (usually the current locales language),
+        the language itself (native) and in English (the source language);
+        e.g. ``ja`` (Japanese) for ``de`` (German) locale
+        is ``('Japanisch', '日本語', 'Japanese')``.
+    """
+    result = {}
+    codes = ['en'] + get_available_language_codes()
+
+    for c in codes:
+
+        try:
+            # A dict with one specific language and how its name is
+            # represented in all other languages.
+            # e.g. "Japanese" in "de" is "Japanisch"
+            # e.g. "Deutsch" in "es" is "alemán"
+            lang = languages.names[c]
+
+        except KeyError:
+            names = None
+
+        else:
+            names = (
+                # in currents locale language
+                lang[language_code],
+                # native
+                lang['_native'],
+                # in English (source language)
+                lang['en']
+            )
+
+        result[c] = names
+
+    return result
+
+
+def get_native_language_and_completeness(language_code):
+    """Return the language name in its native flavor and the completeness of
+    its translation in percent.
+
+    Args:
+        language_code(str): The language code.
+
+    Returns:
+        A two-entry tuple with language name as string and a percent as
+        integer.
+    """
+    name = languages.names[language_code][language_code]
+    completeness = languages.completeness[language_code]
+
+    return (name, completeness)
+
+
+# |------------------------------------|
+# | Miscellaneous, not categorized yet |
+# |------------------------------------|
 
 def backintimePath(*path):
     """
@@ -109,7 +317,7 @@ def registerBackintimePath(*path):
     can discover them.
 
     Args:
-        *path (str):    paths that should be joind to 'backintime'
+        *path (str):    paths that should be joined to 'backintime'
 
     Note:
         Duplicate in :py:func:`qt/qttools.py` because modules in qt folder
@@ -216,7 +424,7 @@ def readFileLines(path, default = None):
         default (list):         default if ``path`` does not exist
 
     Returns:
-        list:                   content of file in ``path`` splitted by lines.
+        list:                   content of file in ``path`` split by lines.
     """
     ret_val = default
 
@@ -467,9 +675,17 @@ def checkXServer():
     """
     Check if there is a X11 server running on this system.
 
+    Use ``is_Qt5_working`` instead if you want to be sure that Qt5 is working.
+
     Returns:
         bool:   ``True`` if X11 server is running
     """
+    # Note: Return values of xdpyinfo <> 0 are not clearly documented.
+    #       xdpyinfo does indeed return 1 if it prints
+    #           xdypinfo: unable to open display "..."
+    #       This seems to be undocumented (at least not in the man pages)
+    #       and the source is not obvious here:
+    #       https://cgit.freedesktop.org/xorg/app/xdpyinfo/tree/xdpyinfo.c
     if checkCommand('xdpyinfo'):
         proc = subprocess.Popen(['xdpyinfo'],
                                 stdout = subprocess.DEVNULL,
@@ -479,12 +695,74 @@ def checkXServer():
     else:
         return False
 
+
+def is_Qt5_working(systray_required=False):
+    """
+    Check if the Qt5 GUI library is working (installed and configured)
+
+    This function is contained in BiT CLI (not BiT Qt) to allow Qt5
+    diagnostics output even if the BiT Qt GUI is not installed.
+    This function does NOT add a hard Qt5 dependency (just "probing")
+    so it is OK to be in BiT CLI.
+
+    Args:
+        systray_required: Set to ``True`` if the systray of the desktop
+        environment must be available too to consider Qt5 as "working"
+
+    Returns:
+        bool: ``True``  Qt5 can create a GUI
+              ``False`` Qt5 fails (or the systray is not available
+                        if ``systray_required`` is ``True``)
+    """
+
+    # Spawns a new process since it may crash with a SIGABRT and we
+    # don't want to crash BiT if this happens...
+
+    try:
+        path = os.path.join(backintimePath("common"), "qt5_probing.py")
+        cmd = [sys.executable, path]
+        if logger.DEBUG:
+            cmd.append('--debug')
+
+        with subprocess.Popen(cmd,
+                              stdout=subprocess.PIPE,
+                              stderr=subprocess.PIPE,
+                              universal_newlines=True) as proc:
+
+            std_output, error_output = proc.communicate(timeout=30)  # to get the exit code
+            # "timeout" fixes #1592 (qt5_probing.py may hang as root): Kill after timeout
+
+            logger.debug(f"Qt5 probing result: exit code {proc.returncode}")
+
+            if proc.returncode != 2 or logger.DEBUG:  # if some Qt5 parts are missing: Show details
+                logger.debug(f"Qt5 probing stdout:\n{std_output}")
+                logger.debug(f"Qt5 probing errout:\n{error_output}")
+
+            return proc.returncode == 2 or (proc.returncode == 1 and systray_required is False)
+
+    except FileNotFoundError:
+        logger.error(f"Qt5 probing script not found: {cmd[0]}")
+        raise
+
+    # Fix for #1592 (qt5_probing.py may hang as root): Kill after timeout
+    except subprocess.TimeoutExpired:
+        proc.kill()
+        outs, errs = proc.communicate()
+        logger.info("Qt5 probing sub process killed after timeout without response")
+        logger.debug(f"Qt5 probing stdout:\n{outs}")
+        logger.debug(f"Qt5 probing errout:\n{errs}")
+
+    except Exception as e:
+        logger.error(f"Error: {repr(e)}")
+        raise
+
+
 def preparePath(path):
     """
     Removes trailing slash '/' from ``path``.
 
     Args:
-        path (str): absolut path
+        path (str): absolute path
 
     Returns:
         str:        path ``path`` without trailing but with leading slash
@@ -845,19 +1123,36 @@ def envSave(f):
     env_file.save(f)
 
 def keyringSupported():
-    if keyring is None:
+    """
+    Checks if a keyring (supported by BiT) is available
+
+    Returns:
+         bool: ``True`` if a supported keyring could be loaded
+    """
+
+    if not is_keyring_available:
         logger.debug('No keyring due to import error.')
         return False
 
+    keyring_config_file_folder = "Unknown"
+    try:
+        keyring_config_file_folder = keyring.util.platform_.config_root()
+    except:
+        pass
+
+    logger.debug(f"Keyring config file folder: {keyring_config_file_folder}")
+
     # Determine the currently active backend
     try:
         # get_keyring() internally calls keyring.core.init_backend()
         # which fixes non-available backends for the first call.
         # See related issue #1321:
         # https://github.com/bit-team/backintime/issues/1321
+        # The module name is used instead of the class name
+        # to show only the keyring name (not the technical name)
         displayName = keyring.get_keyring().__module__
     except:
-        displayName = str(keyring.get_keyring())
+        displayName = str(keyring.get_keyring())  # technical class name!
 
     logger.debug("Available keyring backends:")
     try:
@@ -872,29 +1167,46 @@ def keyringSupported():
     # This is done by trying to put the meta classes ("class definitions",
     # NOT instances of the class itself!) of the supported backends
     # into the "backends" list
-    try: available_backends.append(keyring.backends.SecretService.Keyring)
-    except Exception as e: logger.debug("Metaclass keyring.backends.SecretService.Keyring not found: " + repr(e))
-    try: available_backends.append(keyring.backends.Gnome.Keyring)
-    except Exception as e: logger.debug("Metaclass keyring.backends.Gnome.Keyring not found: " + repr(e))
-    try: available_backends.append(keyring.backends.kwallet.Keyring)
-    except Exception as e: logger.debug("Metaclass keyring.backends.kwallet.Keyring not found: " + repr(e))
-    try: available_backends.append(keyring.backends.kwallet.DBusKeyring)
-    except Exception as e: logger.debug("Metaclass keyring.backends.kwallet.DBusKeyring not found: " + repr(e))
-    try: available_backends.append(keyring.backend.SecretServiceKeyring)
-    except Exception as e: logger.debug("Metaclass keyring.backend.SecretServiceKeyring not found: " + repr(e))
-    try: available_backends.append(keyring.backend.GnomeKeyring)
-    except Exception as e: logger.debug("Metaclass keyring.backend.GnomeKeyring not found: " + repr(e))
-    try: available_backends.append(keyring.backend.KDEKWallet)
-    except Exception as e: logger.debug("Metaclass keyring.backend.KDEKWallet not found: " + repr(e))
-    # TODO (Oct. 7, 2022): Should the ChainerBackend also be supported?
-    #                    It could solve the problem of configuring the
-    #                    used backend since it iterates over all of them
-    #                    and seems to be the default backend now.
-    #                    On the other hand it could use a non-supported
-    #                    backend without a chance for BiT to notice this.
-    # See: https://github.com/jaraco/keyring/blob/977ed03677bb0602b91f005461ef3dddf01a49f6/keyring/backends/chainer.py#L11
-    # try: backends.append(keyring.backends.chainer.ChainerBackend)
-    # except Exception as e: logger.debug("Metaclass keyring.backend. not found:" + repr(e))
+
+    backends_to_check = [
+        (keyring.backends, ['SecretService', 'Keyring']),
+        (keyring.backends, ['Gnome', 'Keyring']),
+        (keyring.backends, ['kwallet', 'Keyring']),
+        (keyring.backends, ['kwallet', 'DBusKeyring']),
+        (keyring.backend, ['SecretServiceKeyring']),
+        (keyring.backend, ['GnomeKeyring']),
+        (keyring.backend, ['KDEWallet']),
+        # See issue #1410: ChainerBackend is now supported to solve the
+        # problem of configuring the used backend since it iterates over all
+        # of them and is to be the default backend now. Please read the issue
+        # details to understand the unwanted side-effects the chainer could
+        # bring with it.
+        # See also:
+        # https://github.com/jaraco/keyring/blob/977ed03677bb0602b91f005461ef3dddf01a49f6/keyring/backends/chainer.py#L11  # noqa
+        (keyring.backends, ('chainer', 'ChainerBackend')),
+    ]
+
+    for backend_package, backends in backends_to_check:
+        result = backend_package  # e.g. keyring.backends
+
+        try:
+            # Load the backend step-by-step.
+            # e.g. When the target is "keyring.backends.Gnome.Keyring" then in
+            # a first step "Gnome" part is loaded first and if successful the
+            # "keyring" part.
+            for b in backends:
+                result = getattr(result, b)
+
+        except AttributeError as err:
+            # Debug message if backend is not available.
+            logger.debug('Metaclass {}.{} not found: {}'
+                         .format(backend_package.__name__,
+                                 '.'.join(backends),
+                                 repr(err)))
+
+        else:
+            # Remember the backend class (not an instance) as available.
+            available_backends.append(result)
 
     logger.debug("Available supported backends: " + repr(available_backends))
 
@@ -902,17 +1214,23 @@ def keyringSupported():
         logger.debug("Found appropriate keyring '{}'".format(displayName))
         return True
 
-    logger.debug("No appropriate keyring found. '{}' can't be used with BackInTime".format(displayName))
-    # TODO (Oct. 07, 2022): Write log output indicating possible solutions for this (eg. via a URL)
+    logger.debug(f"No appropriate keyring found. '{displayName}' can't be "
+                 "used with BackInTime.")
+    logger.debug("See https://github.com/bit-team/backintime on how to fix "
+                 "this by creating a keyring config file.")
+
     return False
 
+
 def password(*args):
-    if not keyring is None:
+
+    if is_keyring_available:
         return keyring.get_password(*args)
     return None
 
 def setPassword(*args):
-    if not keyring is None:
+
+    if is_keyring_available:
         return keyring.set_password(*args)
     return False
 
@@ -936,7 +1254,7 @@ def mountpoint(path):
 
 def decodeOctalEscape(s):
     """
-    Decode octal-escaped characters with its ASCII dependance.
+    Decode octal-escaped characters with its ASCII dependence.
     For example '\040' will be a space ' '
 
     Args:
@@ -1170,36 +1488,6 @@ def filesystemMountInfo():
                 [mount_line.strip('\n').split(' ')[:2] for mount_line in mounts]
                 if uuidFromDev(items[0]) != None}
 
-def wrapLine(msg, size=950, delimiters='\t ', new_line_indicator = 'CONTINUE: '):
-    """
-    Wrap line ``msg`` into multiple lines with each shorter than ``size``. Try
-    to break the line on ``delimiters``. New lines will start with
-    ``new_line_indicator``.
-
-    Args:
-        msg (str):                  string that should get wrapped
-        size (int):                 maximum lenght of returned strings
-        delimiters (str):           try to break ``msg`` on these characters
-        new_line_indicator (str):   start new lines with this string
-
-    Yields:
-        str:                        lines with max ``size`` lenght
-    """
-    if len(new_line_indicator) >= size - 1:
-        new_line_indicator = ''
-    while msg:
-        if len(msg) <= size:
-            yield(msg)
-            break
-        else:
-            line = ''
-            for look in range(size-1, size//2, -1):
-                if msg[look] in delimiters:
-                    line, msg = msg[:look+1], new_line_indicator + msg[look+1:]
-                    break
-            if not line:
-                line, msg = msg[:size], new_line_indicator + msg[size:]
-            yield(line)
 
 def syncfs():
     """
@@ -1218,6 +1506,10 @@ def isRoot():
     Returns:
         bool:   ``True`` if we are root
     """
+
+    # The EUID (Effective UID) may be different from the UID (user ID)
+    # in case of SetUID or using "sudo" (where EUID is "root" and UID
+    # is the original user who executed "sudo").
     return os.geteuid() == 0
 
 def usingSudo():
@@ -1225,7 +1517,7 @@ def usingSudo():
     Check if 'sudo' was used to start this process.
 
     Returns:
-        bool:   ``True`` if process was started with sudo
+        bool:   ``True`` if the process was started with sudo
     """
     return isRoot() and os.getenv('HOME', '/root') != '/root'
 
@@ -1336,6 +1628,15 @@ def inhibitSuspend(app_id = sys.argv[0],
     if ON_TRAVIS or dbus is None:
         # no suspend on travis (no dbus either)
         return
+
+    # Fixes #1592 (BiT hangs as root when trying to establish a dbus user session connection)
+    # Side effect: In BiT <= 1.4.1 root still tried to connect to the dbus user session
+    #              and it may have worked sometimes (without logging we don't know)
+    #              so as root suspend can no longer inhibited.
+    if isRoot():
+        logger.debug("Inhibit Suspend failed because BIT was started as root.")
+        return
+
     if not app_id:
         app_id = 'backintime'
     try:
@@ -1352,7 +1653,7 @@ def inhibitSuspend(app_id = sys.argv[0],
             if 'DBUS_SESSION_BUS_ADDRESS' in os.environ:
                 bus = dbus.bus.BusConnection(os.environ['DBUS_SESSION_BUS_ADDRESS'])
             else:
-                bus = dbus.SessionBus()
+                bus = dbus.SessionBus()  # This code may hang forever (if BiT is run as root via cron job and no user is logged in). See #1592
             interface = bus.get_object(dbus_props['service'], dbus_props['objectPath'])
             proxy = interface.get_dbus_method(dbus_props['methodSet'], dbus_props['interface'])
             cookie = proxy(*[(app_id, dbus.UInt32(toplevel_xid), reason, dbus.UInt32(flags))[i] for i in dbus_props['arguments']])
@@ -1360,9 +1661,6 @@ def inhibitSuspend(app_id = sys.argv[0],
             return (cookie, bus, dbus_props)
         except dbus.exceptions.DBusException:
             pass
-    if isRoot():
-        logger.debug("Inhibit Suspend failed because BIT was started as root.")
-        return
     logger.warning('Inhibit Suspend failed.')
 
 def unInhibitSuspend(cookie, bus, dbus_props):
@@ -1407,7 +1705,7 @@ def readCrontab():
             crontab = [x.strip() for x in out.strip('\n').split('\n')]
             if crontab == ['']:  # Fixes issue #1181 (line count of empty crontab was 1 instead of 0)
                 crontab = []
-            logger.debug('Read %s lines from users crontab'
+            logger.debug('Read %s lines from user crontab'
                          %len(crontab))
             return crontab
 
@@ -1444,7 +1742,7 @@ def writeCrontab(lines):
                      %(proc.returncode, err))
         return False
     else:
-        logger.debug('Wrote %s lines to users crontab'
+        logger.debug('Wrote %s lines to user crontab'
                      %len(lines))
         return True
 
@@ -1602,13 +1900,13 @@ class UniquenessSet:
             size,inode  = dum.st_size, dum.st_ino
             # is it a hlink ?
             if (size, inode) in self._size_inode:
-                logger.debug("[deep test] : skip, it's a duplicate (size, inode)", self)
+                logger.debug("[deep test]: skip, it's a duplicate (size, inode)", self)
                 return False
             self._size_inode.add((size,inode))
             if size not in self._uniq_dict:
                 # first item of that size
                 unique_key = size
-                logger.debug("[deep test] : store current size ?", self)
+                logger.debug("[deep test]: store current size?", self)
             else:
                 prev = self._uniq_dict[size]
                 if prev:
@@ -1616,16 +1914,16 @@ class UniquenessSet:
                     md5sum_prev = md5sum(prev)
                     self._uniq_dict[size] = None
                     self._uniq_dict[md5sum_prev] = prev
-                    logger.debug("[deep test] : size duplicate, remove the size, store prev md5sum", self)
+                    logger.debug("[deep test]: size duplicate, remove the size, store prev md5sum", self)
                 unique_key = md5sum(path)
-                logger.debug("[deep test] : store current md5sum ?", self)
+                logger.debug("[deep test]: store current md5sum?", self)
         else:
             # store a tuple of (size, modification time)
             obj  = os.stat(path)
             unique_key = (obj.st_size, int(obj.st_mtime))
         # store if not already present, then return True
         if unique_key not in self._uniq_dict:
-            logger.debug(" >> ok, store !", self)
+            logger.debug(" >> ok, store!", self)
             self._uniq_dict[unique_key] = path
             return True
         logger.debug(" >> skip (it's a duplicate)", self)
@@ -1666,12 +1964,12 @@ class Alarm(object):
         Args:
             callback: Function to call when the timer ran down
                       (ensure calling only reentrant code).
-                      Use ``None`` toi throws a ``Timeout`` exception instead.
+                      Use ``None`` to throw a ``Timeout`` exception instead.
             overwrite: Is it allowed to (re)start the timer
                        even though the current timer is still running
                        ("ticking"):
                        ``True`` cancels the current timer (if active)
-                                and restarts with the new timout.
+                                and restarts with the new timeout.
                        ``False` silently ignores the start request
                                 if the current timer is still "ticking"
         """
@@ -1773,7 +2071,7 @@ class ShutDown(object):
                                 'arguments':    (True,)
                                     #arg        True    allow saving
                                     #           False   don't allow saving
-                                    #1nd arg (only with Logout)
+                                    #1st arg (only with Logout)
                                     #           True    show dialog
                                     #           False   don't show dialog
                                     #2nd arg (only with Logout)
@@ -1947,7 +2245,7 @@ class SetupUdev(object):
 
     def addRule(self, cmd, uuid):
         """
-        Prepair rules in serviceHelper.py
+        Prepare rules in serviceHelper.py
         """
         if not self.isReady:
             return
@@ -2094,11 +2392,13 @@ class Execute(object):
                             by either :py:func:`os.system` (deprecated) or
                             :py:class:`subprocess.Popen`
         callback (method):  function which will handle output returned by
-                            command
+                            command (e.g. to extract errors)
         user_data:          extra arguments which will be forwarded to
-                            ``callback`` function
+                            ``callback`` function (e.g. a tuple - which is
+                            passed by reference in Python - to "return"
+                            results of the callback function as side effect).
         filters (tuple):    Tuple of functions used to filter messages before
-                            sending them to ``callback``
+                            sending them to the ``callback`` function
         parent (instance):  instance of the calling method used only to proper
                             format log messages
         conv_str (bool):    convert output to :py:class:`str` if True or keep it
@@ -2106,8 +2406,9 @@ class Execute(object):
         join_stderr (bool): join stderr to stdout
 
     Note:
-        Signals SIGTSTP and SIGCONT send to Python main process will be
-        forwarded to the command. SIGHUP will kill the process.
+        Signals SIGTSTP ("keyboard stop") and SIGCONT send to Python
+        main process will be forwarded to the command.
+        SIGHUP will kill the process.
     """
     def __init__(self,
                  cmd,
@@ -2124,7 +2425,7 @@ class Execute(object):
         self.currentProc = None
         self.conv_str = conv_str
         self.join_stderr = join_stderr
-        #we need to forward parent to have the correct class name in debug log
+        # we need to forward parent to have the correct class name in debug log
         if parent:
             self.parent = parent
         else:
@@ -2144,12 +2445,14 @@ class Execute(object):
         Start the command.
 
         Returns:
-            int:    returncode from command
+            int:    return code from the command
         """
         ret_val = 0
         out = ''
 
-        #backwards compatibility with old os.system and os.popen calls
+        # backwards compatibility with old os.system and os.popen calls
+        # TODO Is this still required as the minimal Python version is 3.10++ now?
+        # TODO Which Python versions are considered as "old" here?
         if isinstance(self.cmd, str):
             logger.deprecated(self)
             if self.callback is None:
@@ -2172,24 +2475,41 @@ class Execute(object):
                 if ret_val is None:
                     ret_val = 0
 
-        #new and preferred method using subprocess.Popen
+        # new and preferred method using subprocess.Popen
+        # TODO Which minimal Python version is required to be considered as "new"?
         elif isinstance(self.cmd, (list, tuple)):
             try:
-                #register signals for pause, resume and kill
+                # register signals for pause, resume and kill
+                # Forward these signals (sent to the "backintime" process
+                # normally) to the child process ("rsync" normally).
+                # Note: SIGSTOP (unblockable stop) cannot be forwarded because
+                # it cannot be caught in a signal handler!
                 signal.signal(signal.SIGTSTP, self.pause)
                 signal.signal(signal.SIGCONT, self.resume)
                 signal.signal(signal.SIGHUP, self.kill)
             except ValueError:
-                #signal only work in qt main thread
+                # signal only work in qt main thread
+                # TODO What does this imply?
                 pass
 
             if self.join_stderr:
                 stderr = subprocess.STDOUT
             else:
                 stderr = subprocess.DEVNULL
+
+            logger.debug(f"Starting command '{self.printable_cmd[:min(16, len(self.printable_cmd))]}...'")
+
             self.currentProc = subprocess.Popen(self.cmd,
                                                 stdout = subprocess.PIPE,
                                                 stderr = stderr)
+
+            # # TEST code for developers to simulate a killed rsync process
+            # if self.printable_cmd.startswith("rsync --recursive"):
+            #     self.currentProc.terminate()  # signal 15 (SIGTERM) like "killall" and "kill" do by default
+            #     # self.currentProc.send_signal(signal.SIGHUP)  # signal 1
+            #     # self.currentProc.kill()  # signal 9
+            #     logger.error("rsync killed for testing purposes during development")
+
             if self.callback:
                 for line in self.currentProc.stdout:
                     if self.conv_str:
@@ -2202,16 +2522,27 @@ class Execute(object):
                         continue
                     self.callback(line, self.user_data)
 
+            # We use communicate() instead of wait() to avoid a deadlock
+            # when stdout=PIPE and/or stderr=PIPE and the child process
+            # generates enough output to pipe that it blocks waiting for
+            # free buffer. See also:
+            # https://docs.python.org/3.10/library/subprocess.html#subprocess.Popen.wait
             out = self.currentProc.communicate()[0]
+            # TODO Why is "out" empty instead of containing all stdout?
+            #      Most probably because Popen was called with a PIPE as stdout
+            #      to directly process each stdout line by calling the callback...
+
             ret_val = self.currentProc.returncode
+            # TODO ret_val is sometimes 0 instead of e.g. 23 for rsync. Why?
 
             try:
-                #reset signals to their default
+                # reset signal handler to their default
                 signal.signal(signal.SIGTSTP, signal.SIG_DFL)
                 signal.signal(signal.SIGCONT, signal.SIG_DFL)
                 signal.signal(signal.SIGHUP, signal.SIG_DFL)
             except ValueError:
-                #signal only work in qt main thread
+                # signal only work in qt main thread
+                # TODO What does this imply?
                 pass
 
         if ret_val != 0:
@@ -2336,7 +2667,7 @@ class Daemon:
         """
         # Check for a pidfile to see if the daemon already runs
         if self.pidfile and not self.appInstance.check():
-            message = "pidfile %s already exist. Daemon already running?\n"
+            message = "pidfile %s already exists. Daemon already running?\n"
             logger.error(message % self.pidfile, self)
             sys.exit(1)
 
@@ -2423,13 +2754,33 @@ class Daemon:
         """
         pass
 
-def __logKeyringWarning():
-    from time import sleep
-    sleep(0.1)
-    logger.warning('import keyring failed')
-
-if keyring is None and keyring_warn:
-    #delay warning to give logger some time to import
-    from threading import Thread
-    thread = Thread(target = __logKeyringWarning, args = ())
-    thread.start()
+# def __logKeyringWarning():
+#
+#     from time import sleep
+#     sleep(0.1)
+#     # TODO This function may not be thread-safe
+#     logger.warning('import keyring failed')
+#
+#
+#
+# if is_keyring_available:
+#
+#     # delay warning to give logger some time to import
+#
+#     # Jan 4, 2024 aryoda:
+#     # This is an assumed work-around for #820 (unhandled exception: NoneType)
+#     # but does not seem to fix the problem.
+#     # So I have refactored the possible name shadowing of "keyring"
+#     # as described in
+#     # https://github.com/bit-team/backintime/issues/820#issuecomment-1472971734
+#     # and left this code unchanged to wait for user feed-back if it works now.
+#     # If the error still occurs I would move the log output call
+#     # to the client of this module so that it is certain to assume it is
+#     # correctly initialized.
+#     # Maybe use backintime.py and app.py for logging...
+#     # (don't call tools.keyringSupported() for that because
+#     # it produces too much debug logging output whenever it is called
+#     # but just query tools.is_keyring_available.
+#     from threading import Thread
+#     thread = Thread(target=__logKeyringWarning, args=())
+#     thread.start()
