@@ -16,8 +16,6 @@
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
-import gettext
-
 from PyQt5.QtGui import *
 from PyQt5.QtWidgets import *
 from PyQt5.QtCore import *
@@ -29,11 +27,18 @@ import snapshotlog
 import tools
 import messagebox
 
-_=gettext.gettext
-
 
 class LogViewDialog(QDialog):
     def __init__(self, parent, sid = None, systray = False):
+        """
+        Instantiate a snapshot log file viewer
+
+        Args:
+            parent:
+            sid (:py:class:`SID`): snapshot ID whose log file shall be shown
+                                   (``None`` = show last log)
+            systray (bool): TODO Show log from systray icon or from App (boolean)
+        """
         if systray:
             super(LogViewDialog, self).__init__()
         else:
@@ -63,15 +68,15 @@ class LogViewDialog(QDialog):
         layout = QHBoxLayout()
         self.mainLayout.addLayout(layout)
 
-        #profiles
-        self.lblProfile = QLabel(_('Profile:'), self)
+        # profiles
+        self.lblProfile = QLabel(_('Profile') + ':', self)
         layout.addWidget(self.lblProfile)
 
         self.comboProfiles = qttools.ProfileCombo(self)
         layout.addWidget(self.comboProfiles, 1)
         self.comboProfiles.currentIndexChanged.connect(self.profileChanged)
 
-        #snapshots
+        # snapshots
         self.lblSnapshots = QLabel(_('Snapshots') + ':', self)
         layout.addWidget(self.lblSnapshots)
         self.comboSnapshots = qttools.SnapshotCombo(self)
@@ -85,21 +90,27 @@ class LogViewDialog(QDialog):
             self.lblProfile.hide()
             self.comboProfiles.hide()
 
-        #filter
-        layout.addWidget(QLabel(_('Filter:')))
+        # filter
+        layout.addWidget(QLabel(_('Filter') + ':'))
 
         self.comboFilter = QComboBox(self)
         layout.addWidget(self.comboFilter, 1)
         self.comboFilter.currentIndexChanged.connect(self.comboFilterChanged)
 
-        self.comboFilter.addItem(_('All'), 0)
-        self.comboFilter.addItem(' + '.join((_('Errors'), _('Changes'))), 4)
-        self.comboFilter.setCurrentIndex(self.comboFilter.count() - 1)
-        self.comboFilter.addItem(_('Errors'), 1)
-        self.comboFilter.addItem(_('Changes'), 2)
-        self.comboFilter.addItem(_('Informations'), 3)
+        self.comboFilter.addItem(_('All'), snapshotlog.LogFilter.NO_FILTER)
 
-        #text view
+        # Note about ngettext plural forms: n=102 means "Other" in Arabic and
+        # "Few" in Polish.
+        # Research in translation community indicate this as the best fit to
+        # the meaning of "all".
+        self.comboFilter.addItem(' + '.join((_('Errors'), _('Changes'))), snapshotlog.LogFilter.ERROR_AND_CHANGES)
+        self.comboFilter.setCurrentIndex(self.comboFilter.count() - 1)
+        self.comboFilter.addItem(_('Errors'), snapshotlog.LogFilter.ERROR)
+        self.comboFilter.addItem(_('Changes'), snapshotlog.LogFilter.CHANGES)
+        self.comboFilter.addItem(_('Information'), snapshotlog.LogFilter.INFORMATION)
+        self.comboFilter.addItem(_('rsync transfer failures (experimental)'), snapshotlog.LogFilter.RSYNC_TRANSFER_FAILURES)
+
+        # text view
         self.txtLogView = QPlainTextEdit(self)
         self.txtLogView.setFont(QFont('Monospace'))
         self.txtLogView.setReadOnly(True)
@@ -129,7 +140,7 @@ class LogViewDialog(QDialog):
             # only watch if we show the last log
             log = self.config.takeSnapshotLogFile(self.comboProfiles.currentProfileID())
             self.watcher.addPath(log)
-        self.watcher.fileChanged.connect(self.updateLog)
+        self.watcher.fileChanged.connect(self.updateLog)  # passes the path to the changed file to updateLog()
 
         self.txtLogView.setContextMenuPolicy(Qt.CustomContextMenu)
         self.txtLogView.customContextMenuRequested.connect(self.contextMenuClicked)
@@ -191,10 +202,20 @@ class LogViewDialog(QDialog):
         edit = QLineEdit(self)
         edit.setText(path)
         edit.setMinimumWidth(600)
-        options = {'widget': edit, 'retFunc': edit.text, 'id': 'path'}
-        confirm, opt = messagebox.warningYesNoOptions(self, _("Do you want to exclude this?"), (options, ))
+        options = {
+            'widget': edit,
+            'retFunc': edit.text,
+            'id': 'path'
+        }
+        confirm, opt = messagebox.warningYesNoOptions(
+            self,
+            _('Do you want to exclude this?'),
+            (options, )
+        )
+
         if not confirm:
             return
+
         exclude.append(opt['path'])
         self.config.setExclude(exclude)
 
@@ -241,11 +262,24 @@ class LogViewDialog(QDialog):
                 self.cbDecode.setChecked(False)
 
     def updateLog(self, watchPath = None):
+        """
+        Show the log file of the current snapshot in the GUI
+
+        Args:
+            watchPath: FQN to a log file (as string) whose changes are watched
+                       via ``QFileSystemWatcher``. In case of changes
+                       this function is called with the log file
+                       and only the new lines in the log file are appended
+                       to the log file widget in the GUI
+                       Use ``None`` if a complete log file shall be shown
+                       at once.
+        """
         if not self.enableUpdate:
             return
 
         mode = self.comboFilter.itemData(self.comboFilter.currentIndex())
 
+        # TODO This expressions is hard to understand (watchPath is not a boolean!)
         if watchPath and self.sid is None:
             # remove path from watch to prevent multiple updates at the same time
             self.watcher.removePath(watchPath)
