@@ -14,18 +14,16 @@
 #    with this program; if not, write to the Free Software Foundation, Inc.,
 #    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-import gettext
 from PyQt5.QtCore import QTimer, Qt
 from PyQt5.QtWidgets import QApplication, QMessageBox, QInputDialog, QLineEdit,\
     QDialog, QVBoxLayout, QLabel, QDialogButtonBox, QScrollArea
 import qttools
 
-_ = gettext.gettext
 
-def askPasswordDialog(parent, title, prompt, timeout = None):
+def askPasswordDialog(parent, title, prompt, language_code, timeout):
     if parent is None:
         app = qttools.createQApplication()
-        translator = qttools.translator()
+        translator = qttools.initiate_translator(language_code)
         app.installTranslator(translator)
 
     import icon
@@ -54,8 +52,28 @@ def askPasswordDialog(parent, title, prompt, timeout = None):
 
     return(password)
 
+def info(text, title=None, widget_to_center_on=None):
+    """Show a modal information message box.
+
+    The message box is centered on the primary screen if
+    ``widget_to_center_on`` is not given.
+
+    Args:
+        text(str): The information text central to the dialog.
+        title(str): Title of the message box dialog.
+        widget_to_center_on(QWidget): Center the message box on that widget.
+
+    Returns:
+        Nothing.
+    """
+    QMessageBox.information(
+        widget_to_center_on,
+        title if title else _('Information'),
+        text)
+
 def critical(parent, msg):
-    return QMessageBox.critical(parent, _('Error'),
+    return QMessageBox.critical(parent,
+                                _('Error'),
                                 msg,
                                 buttons = QMessageBox.Ok,
                                 defaultButton = QMessageBox.Ok)
@@ -66,25 +84,43 @@ def warningYesNo(parent, msg):
                                 defaultButton = QMessageBox.No)
 
 def warningYesNoOptions(parent, msg, options = ()):
+
+    # Create a dialog
     dlg = QDialog(parent)
     dlg.setWindowTitle(_('Question'))
     layout = QVBoxLayout()
     dlg.setLayout(layout)
+
+    # Initial message
     label = QLabel(msg)
     layout.addWidget(label)
 
+    # Add optional elements
     for opt in options:
         layout.addWidget(opt['widget'])
 
+    # Button box
     buttonBox = QDialogButtonBox(QDialogButtonBox.Yes | QDialogButtonBox.No)
     buttonBox.button(QDialogButtonBox.No).setDefault(True)
     layout.addWidget(buttonBox)
     buttonBox.accepted.connect(dlg.accept)
     buttonBox.rejected.connect(dlg.reject)
+
+    # Show and ask user for the answer
     ret = dlg.exec_()
-    return (ret, {opt['id']:opt['retFunc']() for opt in options if opt['retFunc'] is not None})
+
+    return (
+        ret,
+        {
+            opt['id']:opt['retFunc']()
+            for opt in options
+            if opt['retFunc'] is not None
+        }
+    )
 
 def showInfo(parent, title, msg):
+    """Show extended information dialog with framed and scrollable text area.
+    """
     dlg = QDialog(parent)
     dlg.setWindowTitle(title)
     vlayout = QVBoxLayout(dlg)
