@@ -19,9 +19,7 @@
 
 import os
 import datetime
-import gettext
 import copy
-import grp
 import re
 
 from PyQt5.QtGui import QIcon, QFont, QPalette, QBrush, QColor
@@ -69,8 +67,6 @@ import sshtools
 import logger
 from exceptions import MountException, NoPubKeyLogin, KnownHost
 
-_ = gettext.gettext
-
 
 class SettingsDialog(QDialog):
     def __init__(self, parent):
@@ -88,7 +84,7 @@ class SettingsDialog(QDialog):
         self.config.setErrorHandler(self.errorHandler)
 
         self.setWindowIcon(icon.SETTINGS_DIALOG)
-        self.setWindowTitle(_('Settings'))
+        self.setWindowTitle(_('Manage profiles'))
 
         self.mainLayout = QVBoxLayout(self)
 
@@ -96,7 +92,7 @@ class SettingsDialog(QDialog):
         layout = QHBoxLayout()
         self.mainLayout.addLayout(layout)
 
-        layout.addWidget(QLabel(_('Profile:'), self))
+        layout.addWidget(QLabel(_('Profile') + ':', self))
 
         self.firstUpdateAll = True
         self.disableProfileChanged = True
@@ -109,16 +105,6 @@ class SettingsDialog(QDialog):
         self.btnEditProfile.clicked.connect(self.editProfile)
         layout.addWidget(self.btnEditProfile)
 
-        # update to full system backup button
-        self.btnModifyProfileForFullSystemBackup \
-            = QPushButton(icon.ADD, _('Modify for Full System Backup'), self)
-        self.btnModifyProfileForFullSystemBackup \
-            .clicked.connect(self.modifyProfileForFullSystemBackup)
-        layout.addWidget(self.btnModifyProfileForFullSystemBackup)
-
-        # hide 'full system backup button' until all dev regarding this is done
-        self.btnModifyProfileForFullSystemBackup.hide()
-
         self.btnAddProfile = QPushButton(icon.ADD, _('Add'), self)
         self.btnAddProfile.clicked.connect(self.addProfile)
         layout.addWidget(self.btnAddProfile)
@@ -148,7 +134,7 @@ class SettingsDialog(QDialog):
         vlayout = QVBoxLayout()
         layout.addLayout(vlayout)
 
-        self.lblModes = QLabel(_('Mode:'), self)
+        self.lblModes = QLabel(_('Mode') + ':', self)
 
         self.comboModes = QComboBox(self)
         hlayout = QHBoxLayout()
@@ -161,12 +147,13 @@ class SettingsDialog(QDialog):
         self.fillCombo(self.comboModes, store_modes)
 
         # encfs security warning
-        self.encfsWarning = QLabel(
-            _('<b>Warning:</b> %(app)s uses EncFS for encryption. A recent '
-              'security audit revealed several possible attack vectors for '
-              'this. Please take a look at "A NOTE ON SECURITY" in '
-              '"man backintime".') % {'app': self.config.APP_NAME}
-        )
+        self.encfsWarning = QLabel('<b>{}:</b> {}'.format(
+            _('Warning'),
+            _('{app} uses EncFS for encryption. A recent security audit '
+              'revealed several possible attack vectors for this. Please '
+              'take a look at "A NOTE ON SECURITY" in "man backintime".')
+            .format(app=self.config.APP_NAME)
+        ))
         self.encfsWarning.setWordWrap(True)
         layout.addWidget(self.encfsWarning)
 
@@ -209,34 +196,34 @@ class SettingsDialog(QDialog):
         hlayout3 = QHBoxLayout()
         vlayout.addLayout(hlayout3)
 
-        self.lblSshHost = QLabel(_('Host:'), self)
+        self.lblSshHost = QLabel(_('Host') + ':', self)
         hlayout1.addWidget(self.lblSshHost)
         self.txtSshHost = QLineEdit(self)
         hlayout1.addWidget(self.txtSshHost)
 
-        self.lblSshPort = QLabel(_('Port:'), self)
+        self.lblSshPort = QLabel(_('Port') + ':', self)
         hlayout1.addWidget(self.lblSshPort)
         self.txtSshPort = QLineEdit(self)
         hlayout1.addWidget(self.txtSshPort)
 
-        self.lblSshUser = QLabel(_('User:'), self)
+        self.lblSshUser = QLabel(_('User') + ':', self)
         hlayout1.addWidget(self.lblSshUser)
         self.txtSshUser = QLineEdit(self)
         hlayout1.addWidget(self.txtSshUser)
 
-        self.lblSshPath = QLabel(_('Path:'), self)
+        self.lblSshPath = QLabel(_('Path') + ':', self)
         hlayout2.addWidget(self.lblSshPath)
         self.txtSshPath = QLineEdit(self)
         self.txtSshPath.textChanged.connect(self.fullPathChanged)
         hlayout2.addWidget(self.txtSshPath)
 
-        self.lblSshCipher = QLabel(_('Cipher:'), self)
+        self.lblSshCipher = QLabel(_('Cipher') + ':', self)
         hlayout3.addWidget(self.lblSshCipher)
         self.comboSshCipher = QComboBox(self)
         hlayout3.addWidget(self.comboSshCipher)
         self.fillCombo(self.comboSshCipher, self.config.SSH_CIPHERS)
 
-        self.lblSshPrivateKeyFile = QLabel(_('Private Key:'), self)
+        self.lblSshPrivateKeyFile = QLabel(_('Private Key') + ':', self)
         hlayout3.addWidget(self.lblSshPrivateKeyFile)
         self.txtSshPrivateKeyFile = QLineEdit(self)
         self.txtSshPrivateKeyFile.setReadOnly(True)
@@ -245,7 +232,8 @@ class SettingsDialog(QDialog):
         self.btnSshPrivateKeyFile = QToolButton(self)
         self.btnSshPrivateKeyFile.setToolButtonStyle(Qt.ToolButtonIconOnly)
         self.btnSshPrivateKeyFile.setIcon(icon.FOLDER)
-        self.btnSshPrivateKeyFile.setToolTip(_('Choose an existing private key file (normally named "id_rsa")'))
+        self.btnSshPrivateKeyFile.setToolTip(
+            _('Choose an existing private key file (normally named "id_rsa")'))
         self.btnSshPrivateKeyFile.setMinimumSize(32, 28)
         hlayout3.addWidget(self.btnSshPrivateKeyFile)
         self.btnSshPrivateKeyFile.clicked \
@@ -255,7 +243,8 @@ class SettingsDialog(QDialog):
         self.btnSshKeyGen.setToolButtonStyle(Qt.ToolButtonIconOnly)
         self.btnSshKeyGen.setIcon(icon.ADD)
         self.btnSshKeyGen.setToolTip(
-            _('Create a new SSH key without password (not allowed if a private key file is already selected)'))
+            _('Create a new SSH key without password (not allowed if a '
+              'private key file is already selected)'))
         self.btnSshKeyGen.setMinimumSize(32, 28)
         hlayout3.addWidget(self.btnSshKeyGen)
         self.btnSshKeyGen.clicked.connect(self.btnSshKeyGenClicked)
@@ -326,25 +315,25 @@ class SettingsDialog(QDialog):
         hlayout2 = QHBoxLayout()
         vlayout2.addLayout(hlayout2)
 
-        self.lblHost = QLabel(_('Host:'), self)
+        self.lblHost = QLabel(_('Host') + ':', self)
         hlayout2.addWidget(self.lblHost)
         self.txtHost = QLineEdit(self)
         self.txtHost.textChanged.connect(self.fullPathChanged)
         hlayout2.addWidget(self.txtHost)
 
-        self.lblUser = QLabel(_('User:'), self)
+        self.lblUser = QLabel(_('User') + ':', self)
         hlayout2.addWidget(self.lblUser)
         self.txtUser = QLineEdit(self)
         self.txtUser.textChanged.connect(self.fullPathChanged)
         hlayout2.addWidget(self.txtUser)
 
-        self.lblProfile = QLabel(_('Profile:'), self)
+        self.lblProfile = QLabel(_('Profile') + ':', self)
         hlayout2.addWidget(self.lblProfile)
         self.txt_profile = QLineEdit(self)
         self.txt_profile.textChanged.connect(self.fullPathChanged)
         hlayout2.addWidget(self.txt_profile)
 
-        self.lblFullPath = QLabel(_('Full snapshot path: '), self)
+        self.lblFullPath = QLabel(_('Full snapshot path') + ': ', self)
         self.lblFullPath.setWordWrap(True)
         vlayout2.addWidget(self.lblFullPath)
 
@@ -359,9 +348,39 @@ class SettingsDialog(QDialog):
 
         self.comboSchedule = QComboBox(self)
         glayout.addWidget(self.comboSchedule, 0, 0, 1, 2)
-        self.fillCombo(self.comboSchedule, self.config.SCHEDULE_MODES)
 
-        self.lblScheduleDay = QLabel(_('Day:'), self)
+        # import gettext
+        # Regular schedule modes for that combo box
+        schedule_modes_dict = {
+            config.Config.NONE: _('Disabled'),
+            config.Config.AT_EVERY_BOOT: _('At every boot/reboot'),
+            config.Config._5_MIN: ngettext(
+                'Every {n} minute', 'Every {n} minutes', 5).format(n=5),
+            config.Config._10_MIN: ngettext(
+                'Every {n} minute', 'Every {n} minutes', 10).format(n=10),
+            config.Config._30_MIN: ngettext(
+                'Every {n} minute', 'Every {n} minutes', 30).format(n=30),
+            config.Config._1_HOUR: _('Every hour'),
+            config.Config._2_HOURS: ngettext(
+                'Every {n} hour', 'Every {n} hours', 2).format(n=2),
+            config.Config._4_HOURS: ngettext(
+                'Every {n} hour', 'Every {n} hours', 4).format(n=4),
+            config.Config._6_HOURS: ngettext(
+                'Every {n} hour', 'Every {n} hours', 6).format(n=6),
+            config.Config._12_HOURS: ngettext(
+                'Every {n} hour', 'Every {n} hours', 12).format(n=12),
+            config.Config.CUSTOM_HOUR: _('Custom hours'),
+            config.Config.DAY: _('Every day'),
+            config.Config.REPEATEDLY: _('Repeatedly (anacron)'),
+            config.Config.UDEV: _('When drive gets connected (udev)'),
+            config.Config.WEEK: _('Every week'),
+            config.Config.MONTH: _('Every month'),
+            config.Config.YEAR: _('Every year')
+        }
+
+        self.fillCombo(self.comboSchedule, schedule_modes_dict)
+
+        self.lblScheduleDay = QLabel(_('Day') + ':', self)
         self.lblScheduleDay.setContentsMargins(5, 0, 0, 0)
         self.lblScheduleDay.setAlignment(Qt.AlignRight | Qt.AlignVCenter)
         glayout.addWidget(self.lblScheduleDay, 1, 0)
@@ -372,7 +391,7 @@ class SettingsDialog(QDialog):
         for d in range(1, 29):
             self.comboScheduleDay.addItem(QIcon(), str(d), d)
 
-        self.lblScheduleWeekday = QLabel(_('Weekday:'), self)
+        self.lblScheduleWeekday = QLabel(_('Weekday') + ':', self)
         self.lblScheduleWeekday.setContentsMargins(5, 0, 0, 0)
         self.lblScheduleWeekday.setAlignment(Qt.AlignRight | Qt.AlignVCenter)
         glayout.addWidget(self.lblScheduleWeekday, 2, 0)
@@ -387,7 +406,7 @@ class SettingsDialog(QDialog):
                 d
             )
 
-        self.lblScheduleTime = QLabel(_('Hour:'), self)
+        self.lblScheduleTime = QLabel(_('Hour') + ':', self)
         self.lblScheduleTime.setContentsMargins(5, 0, 0, 0)
         self.lblScheduleTime.setAlignment(Qt.AlignRight | Qt.AlignVCenter)
         glayout.addWidget(self.lblScheduleTime, 3, 0)
@@ -402,7 +421,7 @@ class SettingsDialog(QDialog):
                 t
             )
 
-        self.lblScheduleCronPatern = QLabel(_('Hours:'), self)
+        self.lblScheduleCronPatern = QLabel(_('Hours') + ':', self)
         self.lblScheduleCronPatern.setContentsMargins(5, 0, 0, 0)
         self.lblScheduleCronPatern.setAlignment(
             Qt.AlignRight | Qt.AlignVCenter)
@@ -420,7 +439,7 @@ class SettingsDialog(QDialog):
         self.lblScheduleRepeated.setWordWrap(True)
         glayout.addWidget(self.lblScheduleRepeated, 5, 0, 1, 2)
 
-        self.lblScheduleRepeatedPeriod = QLabel(_('Every:'))
+        self.lblScheduleRepeatedPeriod = QLabel(_('Every') + ':')
         self.lblScheduleRepeatedPeriod.setContentsMargins(5, 0, 0, 0)
         self.lblScheduleRepeatedPeriod.setAlignment(
             Qt.AlignRight | Qt.AlignVCenter)
@@ -433,8 +452,14 @@ class SettingsDialog(QDialog):
         hlayout.addWidget(self.spbScheduleRepeatedPeriod)
 
         self.comboScheduleRepeatedUnit = QComboBox(self)
+        REPEATEDLY_UNITS = {
+            config.Config.HOUR: _('Hour(s)'),
+            config.Config.DAY: _('Day(s)'),
+            config.Config.WEEK: _('Week(s)'),
+            config.Config.MONTH: _('Month(s)')}
+
         self.fillCombo(self.comboScheduleRepeatedUnit,
-                       self.config.REPEATEDLY_UNITS)
+                       REPEATEDLY_UNITS)
         hlayout.addWidget(self.comboScheduleRepeatedUnit)
         hlayout.addStretch()
         glayout.addLayout(hlayout, 7, 1)
@@ -497,9 +522,17 @@ class SettingsDialog(QDialog):
         layout = QVBoxLayout(tabWidget)
 
         self.lblSshEncfsExcludeWarning = QLabel(
-            _('<b>Warning:</b> Wildcards (\'foo*\', \'[fF]oo\', \'fo?\') '
-              'will be ignored with mode \'SSH encrypted\'.\nOnly separate '
-              'asterisk are allowed (\'foo/*\', \'foo/**/bar\')'), self)
+            "<b>{}:</b> {}".format(
+                _("Warning"),
+                _(
+                    "Wildcards ({example1}) will be ignored "
+                    "with mode 'SSH encrypted'.\nOnly single or double "
+                    "asterisks are allowed ({example2})"
+                ).format(example1="'foo*', '[fF]oo', 'fo?'",
+                         example2="'foo/*', 'foo/**/bar'")
+            ),
+            self
+        )
         self.lblSshEncfsExcludeWarning.setWordWrap(True)
         layout.addWidget(self.lblSshEncfsExcludeWarning)
 
@@ -520,7 +553,7 @@ class SettingsDialog(QDialog):
         layout.addWidget(self.listExclude)
         self.listExcludeCount = 0
 
-        label = QLabel(_('Highly recommended:'), self)
+        label = QLabel(_('Highly recommended') + ':', self)
         qttools.setFontBold(label)
         layout.addWidget(label)
         label = QLabel(', '.join(sorted(self.config.DEFAULT_EXCLUDE)), self)
@@ -563,9 +596,9 @@ class SettingsDialog(QDialog):
               'new files\n'
               'because for rsync this is a transfer option, not an '
               'exclude option.\n'
-              'So big files that has been backed up before will remain '
+              'So big files that have been backed up before will remain '
               'in snapshots\n'
-              'even if they had changed.' % {'prefix': 'MiB'})
+              'even if they have changed.' % {'prefix': 'MiB'})
         )
         hlayout.addWidget(self.cbExcludeBySize)
         self.spbExcludeBySize = QSpinBox(self)
@@ -586,7 +619,7 @@ class SettingsDialog(QDialog):
         layout = QGridLayout(layoutWidget)
 
         # remove old snapshots
-        self.cbRemoveOlder = QCheckBox(_('Older than:'), self)
+        self.cbRemoveOlder = QCheckBox(_('Older than') + ':', self)
         layout.addWidget(self.cbRemoveOlder, 0, 0)
         self.cbRemoveOlder.stateChanged.connect(self.updateRemoveOlder)
 
@@ -596,13 +629,19 @@ class SettingsDialog(QDialog):
 
         self.comboRemoveOlderUnit = QComboBox(self)
         layout.addWidget(self.comboRemoveOlderUnit, 0, 2)
-        self.fillCombo(self.comboRemoveOlderUnit,
-                       self.config.REMOVE_OLD_BACKUP_UNITS)
+
+        REMOVE_OLD_BACKUP_UNITS = {
+            config.Config.DAY: _('Day(s)'),
+            config.Config.WEEK: _('Week(s)'),
+            config.Config.YEAR: _('Year(s)')}
+
+        self.fillCombo(self.comboRemoveOlderUnit, REMOVE_OLD_BACKUP_UNITS)
 
         # min free space
         enabled, value, unit = self.config.minFreeSpace()
 
-        self.cbFreeSpace = QCheckBox(_('If free space is less than:'), self)
+        self.cbFreeSpace = QCheckBox(
+            _('If free space is less than') + ':', self)
         layout.addWidget(self.cbFreeSpace, 1, 0)
         self.cbFreeSpace.stateChanged.connect(self.updateFreeSpace)
 
@@ -612,11 +651,17 @@ class SettingsDialog(QDialog):
 
         self.comboFreeSpaceUnit = QComboBox(self)
         layout.addWidget(self.comboFreeSpaceUnit, 1, 2)
+        MIN_FREE_SPACE_UNITS = {
+            config.Config.DISK_UNIT_MB: 'MiB',
+            config.Config.DISK_UNIT_GB: 'GiB'
+        }
+
         self.fillCombo(self.comboFreeSpaceUnit,
-                       self.config.MIN_FREE_SPACE_UNITS)
+                       MIN_FREE_SPACE_UNITS)
 
         # min free inodes
-        self.cbFreeInodes = QCheckBox(_('If free inodes is less than:'), self)
+        self.cbFreeInodes = QCheckBox(
+            _('If free inodes is less than') + ':', self)
         layout.addWidget(self.cbFreeInodes, 2, 0)
 
         self.spbFreeInodes = QSpinBox(self)
@@ -630,7 +675,7 @@ class SettingsDialog(QDialog):
         self.cbFreeInodes.stateChanged.connect(enabled)
 
         # smart remove
-        self.cbSmartRemove = QCheckBox(_('Smart remove'), self)
+        self.cbSmartRemove = QCheckBox(_('Smart remove:'), self)
         layout.addWidget(self.cbSmartRemove, 3, 0)
 
         widget = QWidget(self)
@@ -640,7 +685,10 @@ class SettingsDialog(QDialog):
         smlayout = QGridLayout(widget)
 
         self.cbSmartRemoveRunRemoteInBackground = QCheckBox(
-            _('Run in background on remote Host.') + _(' EXPERIMENTAL!'),
+            '{} {}!'.format(
+                _('Run in background on remote host.'),
+                _('EXPERIMENTAL')
+            ),
             self)
         smlayout.addWidget(self.cbSmartRemoveRunRemoteInBackground, 0, 0, 1, 3)
 
@@ -649,31 +697,31 @@ class SettingsDialog(QDialog):
         self.spbKeepAll = QSpinBox(self)
         self.spbKeepAll.setRange(1, 10000)
         smlayout.addWidget(self.spbKeepAll, 1, 1)
-        smlayout.addWidget(QLabel(_('day(s)'), self), 1, 2)
+        smlayout.addWidget(QLabel(_('day(s).'), self), 1, 2)
 
         smlayout.addWidget(
             QLabel(_('Keep one snapshot per day for the last'), self), 2, 0)
         self.spbKeepOnePerDay = QSpinBox(self)
         self.spbKeepOnePerDay.setRange(1, 10000)
         smlayout.addWidget(self.spbKeepOnePerDay, 2, 1)
-        smlayout.addWidget(QLabel(_('day(s)'), self), 2, 2)
+        smlayout.addWidget(QLabel(_('day(s).'), self), 2, 2)
 
         smlayout.addWidget(
             QLabel(_('Keep one snapshot per week for the last'), self), 3, 0)
         self.spbKeepOnePerWeek = QSpinBox(self)
         self.spbKeepOnePerWeek.setRange(1, 10000)
         smlayout.addWidget(self.spbKeepOnePerWeek, 3, 1)
-        smlayout.addWidget(QLabel(_('weeks(s)'), self), 3, 2)
+        smlayout.addWidget(QLabel(_('week(s).'), self), 3, 2)
 
         smlayout.addWidget(
             QLabel(_('Keep one snapshot per month for the last'), self), 4, 0)
         self.spbKeepOnePerMonth = QSpinBox(self)
         self.spbKeepOnePerMonth.setRange(1, 1000)
         smlayout.addWidget(self.spbKeepOnePerMonth, 4, 1)
-        smlayout.addWidget(QLabel(_('month(s)'), self), 4, 2)
+        smlayout.addWidget(QLabel(_('month(s).'), self), 4, 2)
 
         smlayout.addWidget(
-            QLabel(_('Keep one snapshot per year for all years'), self),
+            QLabel(_('Keep one snapshot per year for all years.'), self),
             5, 0, 1, 3)
 
         enabled = lambda state: [smlayout.itemAt(x).widget().setEnabled(state) for x in range(smlayout.count())]
@@ -682,7 +730,7 @@ class SettingsDialog(QDialog):
 
         # don't remove named snapshots
         self.cbDontRemoveNamedSnapshots \
-            = QCheckBox(_("Don't remove named snapshots"), self)
+            = QCheckBox(_("Don't remove named snapshots."), self)
         layout.addWidget(self.cbDontRemoveNamedSnapshots, 5, 0, 1, 3)
 
         #
@@ -714,7 +762,7 @@ class SettingsDialog(QDialog):
         self.cbGlobalFlock.setToolTip(
             _('Other snapshots will be blocked until the current snapshot '
               'is done.\n'
-              'This is a global option. So it will effect all profiles '
+              'This is a global option. So it will affect all profiles '
               'for this user.\n'
               'But you need to activate this for all other users, too.')
         )
@@ -723,14 +771,14 @@ class SettingsDialog(QDialog):
         self.cbBackupOnRestore = QCheckBox(
             _('Backup replaced files on restore'), self)
         self.cbBackupOnRestore.setToolTip(
-            _("Newer versions of files will be renamed with "
-              "trailing '%(suffix)s' before restoring.\n"
-              "If you don't need them anymore you can remove them "
-              "with '%(cmd)s'") % {
-                  'suffix': self.snapshots.backupSuffix(),
-                  'cmd': 'find ./ -name "*%s" -delete' %
-                  self.snapshots.backupSuffix()
-              })
+            _("Newer versions of files will be renamed with trailing "
+              "{suffix} before restoring.\n"
+              "If you don't need them anymore you can remove them with {cmd}")
+            .format(suffix=self.snapshots.backupSuffix(),
+                    cmd='find ./ -name "*{suffix}" -delete'
+                        .format(suffix=self.snapshots.backupSuffix())
+                    )
+        )
         layout.addWidget(self.cbBackupOnRestore)
 
         self.cbContinueOnErrors = QCheckBox(
@@ -742,21 +790,28 @@ class SettingsDialog(QDialog):
         layout.addWidget(self.cbUseChecksum)
 
         self.cbTakeSnapshotRegardlessOfChanges = QCheckBox(
-            _('Take a new snapshot regardless of there were changes or not.'))
+            _('Take a new snapshot whether there were changes or not.'))
         layout.addWidget(self.cbTakeSnapshotRegardlessOfChanges)
 
         # log level
         hlayout = QHBoxLayout()
         layout.addLayout(hlayout)
 
-        hlayout.addWidget(QLabel(_('Log Level:'), self))
+        hlayout.addWidget(QLabel(_('Log Level') + ':', self))
 
         self.comboLogLevel = QComboBox(self)
         hlayout.addWidget(self.comboLogLevel, 1)
 
         self.comboLogLevel.addItem(QIcon(), _('None'), 0)
+
+        # Note about ngettext plural forms: n=102 means "Other" in Arabic and
+        # "Few" in Polish.
+        # Research in translation community indicate this as the best fit to
+        # the meaning of "all".
         self.comboLogLevel.addItem(QIcon(), _('Errors'), 1)
-        self.comboLogLevel.addItem(QIcon(), _('Changes & Errors'), 2)
+        self.comboLogLevel.addItem(
+            QIcon(),
+            _('Changes') + ' & ' + _('Errors'), 2)
         self.comboLogLevel.addItem(QIcon(), _('All'), 3)
 
         #
@@ -772,14 +827,12 @@ class SettingsDialog(QDialog):
         layoutWidget = QWidget(self)
         layout = QVBoxLayout(layoutWidget)
 
-        label = QLabel(
-            _('Change these options only if you really know what '
-              'you are doing !'),
-            self)
+        label = QLabel(_('Caution: Change these options only if you really '
+                         'know what you are doing.'), self)
         qttools.setFontBold(label)
         layout.addWidget(label)
 
-        label = QLabel(_("Run 'rsync' with 'nice':"))
+        label = QLabel(_("Run 'rsync' with '{cmd}':").format(cmd='nice'))
         layout.addWidget(label)
         grid = QGridLayout()
         grid.setColumnMinimumWidth(0, 20)
@@ -795,7 +848,7 @@ class SettingsDialog(QDialog):
                 self.config.DEFAULT_RUN_NICE_ON_REMOTE), self)
         grid.addWidget(self.cbNiceOnRemote, 1, 1)
 
-        label = QLabel(_("Run 'rsync' with 'ionice':"))
+        label = QLabel(_("Run 'rsync' with '{cmd}':").format(cmd='ionice'))
         layout.addWidget(label)
         grid = QGridLayout()
         grid.setColumnMinimumWidth(0, 20)
@@ -817,7 +870,8 @@ class SettingsDialog(QDialog):
         grid.addWidget(self.cbIoniceOnRemote, 2, 1)
 
         self.nocacheAvailable = tools.checkCommand('nocache')
-        txt = _("Run 'rsync' with 'nocache':")
+        txt = _("Run 'rsync' with '{cmd}':").format(cmd='nocache')
+
         if not self.nocacheAvailable:
             txt += ' ' + _("(Please install 'nocache' to enable this option)")
         layout.addWidget(QLabel(txt))
@@ -842,7 +896,7 @@ class SettingsDialog(QDialog):
             self)
         self.cbRedirectStdoutInCron.setToolTip(
             'cron will automatically send an email with attached output '
-            'of cronjobs if a MTA is installed.')
+            'of cronjobs if an MTA is installed.')
         layout.addWidget(self.cbRedirectStdoutInCron)
 
         self.cbRedirectStderrInCron = QCheckBox(
@@ -851,16 +905,17 @@ class SettingsDialog(QDialog):
             self)
         self.cbRedirectStderrInCron.setToolTip(
             'cron will automatically send an email with attached errors '
-            'of cronjobs if a MTA is installed.')
+            'of cronjobs if an MTA is installed.')
         layout.addWidget(self.cbRedirectStderrInCron)
 
         # bwlimit
         hlayout = QHBoxLayout()
         layout.addLayout(hlayout)
-        self.cbBwlimit = QCheckBox(_('Limit rsync bandwidth usage: '), self)
+        self.cbBwlimit = QCheckBox(
+            _('Limit rsync bandwidth usage') + ': ', self)
         hlayout.addWidget(self.cbBwlimit)
         self.spbBwlimit = QSpinBox(self)
-        self.spbBwlimit.setSuffix(_(' KB/sec'))
+        self.spbBwlimit.setSuffix(' ' + _('KB/sec'))
         self.spbBwlimit.setSingleStep(100)
         self.spbBwlimit.setRange(0, 1000000)
         hlayout.addWidget(self.spbBwlimit)
@@ -966,13 +1021,14 @@ class SettingsDialog(QDialog):
         # additional rsync options
         hlayout = QHBoxLayout()
         layout.addLayout(hlayout)
+        tooltip = _('Options must be quoted e.g. {example}.').format(
+            example='--exclude-from="/path/to/my exclude file"')
         self.cbRsyncOptions = QCheckBox(
             _('Paste additional options to rsync'), self)
+        self.cbRsyncOptions.setToolTip(tooltip)
         hlayout.addWidget(self.cbRsyncOptions)
         self.txtRsyncOptions = QLineEdit(self)
-        self.txtRsyncOptions.setToolTip(
-            _('Options must be quoted e.g. '
-              '--exclude-from="/path/to/my exclude file".'))
+        self.txtRsyncOptions.setToolTip(tooltip)
         hlayout.addWidget(self.txtRsyncOptions)
 
         enabled = lambda state: self.txtRsyncOptions.setEnabled(state)
@@ -982,21 +1038,22 @@ class SettingsDialog(QDialog):
         # ssh prefix
         hlayout = QHBoxLayout()
         layout.addLayout(hlayout)
+        tooltip = _(
+            'Prefix to run before every command on remote host.\n'
+            'Variables need to be escaped with \\$FOO.\n'
+            'This doesn\'t touch rsync. So to add a prefix\n'
+            'for rsync use "%(cbRsyncOptions)s" with\n'
+            '%(rsync_options_value)s\n\n'
+            '%(default)s: %(def_value)s') % {
+                'cbRsyncOptions': self.cbRsyncOptions.text(),
+                'rsync_options_value': '--rsync-path="FOO=bar:\\$FOO /usr/bin/rsync"',
+                'default': _('default'),
+                'def_value': self.config.DEFAULT_SSH_PREFIX}
         self.cbSshPrefix = QCheckBox(_('Add prefix to SSH commands'), self)
+        self.cbSshPrefix.setToolTip(tooltip)
         hlayout.addWidget(self.cbSshPrefix)
         self.txtSshPrefix = QLineEdit(self)
-        self.txtSshPrefix.setToolTip(
-            _('Prefix to run before every command on remote host.\n'
-              'Variables need to be escaped with \\$FOO.\n'
-              'This doesn\'t touch rsync. So to add a prefix\n'
-              'for rsync use "%(cbRsyncOptions)s" with\n'
-              '%(rsync_options_value)s\n\n'
-              '%(default)s: %(def_value)s') % {
-                  'cbRsyncOptions': self.cbRsyncOptions.text(),
-                  'rsync_options_value': '--rsync-path="FOO=bar:\\$FOO /usr/bin/rsync"',
-                  'default': _('default'),
-                  'def_value': self.config.DEFAULT_SSH_PREFIX}
-        )
+        self.txtSshPrefix.setToolTip(tooltip)
         hlayout.addWidget(self.txtSshPrefix)
 
         enabled = lambda state: self.txtSshPrefix.setEnabled(state)
@@ -1011,7 +1068,7 @@ class SettingsDialog(QDialog):
               'is not available, this could lead to some\n'
               'weird errors.'))
         self.cbSshCheckCommands = QCheckBox(
-            _('Check if remote host support all necessary commands'))
+            _('Check if remote host supports all necessary commands'))
         self.cbSshCheckCommands.setToolTip(
             _('Warning: if disabled and the remote host\n'
               'does not support all necessary commands,\n'
@@ -1048,43 +1105,6 @@ class SettingsDialog(QDialog):
 
         self.finished.connect(self.cleanup)
 
-    def modifyProfileForFullSystemBackup(self):
-        # verify to user that settings will change
-        message = _(
-            "Full system backup can only create a snapshot to be restored "
-            "to the same physical disk(s) with the same disk partitioning "
-            "as from the source; restoring to new physical disks or the "
-            "same disks with different partitioning will yield a potentially "
-            "broken and unusable system.\n\n"
-            "Full system backup will override some settings that may have "
-            "been customized. Continue?"
-        )
-        if QMessageBox.No == messagebox.warningYesNo(self, message):
-            return
-
-        # configure for full system backup
-        # don't want to create a backup with any errors and give user
-        # false sense that backup was ok
-        self.config.setContinueOnErrors(False)
-        # make sure all files are backed up
-        self.config.setExcludeBySize(False, 500)
-        # when we restore the full system, don't want to keep old
-        # files (since we back up everything)
-        self.config.setBackupOnRestore(False)
-        # no need for checksum mode
-        self.config.setUseChecksum(False)
-        # must preserve ACLs and xattrs
-        self.config.setPreserveAcl(True)
-        self.config.setPreserveXattr(True)
-        # don't want links
-        self.config.setCopyLinks(False)
-        self.config.setCopyUnsafeLinks(False)
-        # backup root
-        self.config.setInclude([("/", 0)])
-
-        # set UI
-        self.updateProfiles()
-
     def addProfile(self):
         ret_val = QInputDialog.getText(self, _('New profile'), str())
         if not ret_val[1]:
@@ -1119,8 +1139,9 @@ class SettingsDialog(QDialog):
         self.updateProfiles(reloadSettings=False)
 
     def removeProfile(self):
-        question = _('Are you sure you want to delete the profile "%s" ?') \
-            % self.config.profileName()
+        question = _('Are you sure you want to delete '
+                     'the profile "{name}"?').format(
+                         name=self.config.profileName())
 
         if self.questionHandler(question):
             self.config.removeProfile()
@@ -1392,9 +1413,9 @@ class SettingsDialog(QDialog):
             if not tools.checkCronPattern(self.txtScheduleCronPatern.text()):
 
                 self.errorHandler(
-                    _('Custom Hours can only be a comma separated list of '
+                    _('Custom hours can only be a comma separated list of '
                       'hours (e.g. 8,12,18,23) or */3 for periodic '
-                      'backups every 3 hours')
+                      'backups every 3 hours.')
                 )
 
                 return False
@@ -1445,8 +1466,8 @@ class SettingsDialog(QDialog):
 
             if not os.path.isfile(self.txtSshPrivateKeyFile.text()):
                 self.errorHandler(
-                    _('Private key file "%(file)s" does not exist.')
-                    % {'file': self.txtSshPrivateKeyFile.text()}
+                    _('Private key file "{file}" does not exist.')
+                    .format(file=self.txtSshPrivateKeyFile.text())
                 )
                 self.txtSshPrivateKeyFile.setText('')
 
@@ -1625,18 +1646,18 @@ class SettingsDialog(QDialog):
 
                     return False
 
-                msg = _('The authenticity of host "%(host)s" can\'t be '
-                        'established.\n\n%(keytype)s key fingerprint is:')
-                msg = msg % {'host': self.config.sshHost(),
-                             'keytype': keyType}
+                msg = _("The authenticity of host {host} can't be "
+                        "established.\n\n{keytype} key fingerprint is:") \
+                        .format(host='"{}"'.format(self.config.sshHost()),
+                                keytype=keyType)
                 options = []
                 lblFingerprint = QLabel(fingerprint + '\n')
                 lblFingerprint.setWordWrap(False)
                 lblFingerprint.setFont(QFont('Monospace'))
                 options.append({'widget': lblFingerprint, 'retFunc': None})
                 lblQuestion = QLabel(
-                    _('Please verify this fingerprint! Would you like to '
-                      'add it to your \'known_hosts\' file?')
+                    _("Please verify this fingerprint! Would you like to "
+                      "add it to your 'known_hosts' file?")
                 )
                 options.append({'widget': lblQuestion, 'retFunc': None})
 
@@ -1834,6 +1855,11 @@ class SettingsDialog(QDialog):
             self.listInclude.setCurrentItem(self.listInclude.topLevelItem(0))
 
     def btnIncludeFileClicked(self):
+        """Development Note (buhtz 2023-12):
+        This is a candidate for refactoring. See btnIncludeAddClicked() with
+        much duplicated code.
+        """
+
         for path in qttools.getOpenFileNames(self, _('Include file')):
             if not path:
                 continue
@@ -1841,10 +1867,14 @@ class SettingsDialog(QDialog):
             if os.path.islink(path) \
                 and not (self.cbCopyUnsafeLinks.isChecked()
                          or self.cbCopyLinks.isChecked()):
-                if self.questionHandler(
-                    _('"%s" is a symlink. The linked target will not be '
-                      'backed up until you include it, too.\nWould you like '
-                      'to include the symlinks target instead?') % path):
+
+                question_msg = _(
+                    '"{path}" is a symlink. The linked target will not be '
+                    'backed up until you include it, too.\nWould you like '
+                    'to include the symlink target instead?'
+                ).format(path=path)
+
+                if self.questionHandler(question_msg):
                     path = os.path.realpath(path)
 
             path = self.config.preparePath(path)
@@ -1856,6 +1886,10 @@ class SettingsDialog(QDialog):
             self.addInclude((path, 1))
 
     def btnIncludeAddClicked(self):
+        """Development Note (buhtz 2023-12):
+        This is a candidate for refactoring. See btnIncludeFileClicked() with
+        much duplicated code.
+        """
         for path in qttools.getExistingDirectories(self, _('Include folder')):
             if not path:
                 continue
@@ -1863,10 +1897,13 @@ class SettingsDialog(QDialog):
             if os.path.islink(path) \
                 and not (self.cbCopyUnsafeLinks.isChecked()
                          or self.cbCopyLinks.isChecked()):
-                if self.questionHandler(
-                    _('"%s" is a symlink. The linked target will not be '
-                      'backed up until you include it, too.\nWould you like '
-                      'to include the symlinks target instead?') % path):
+
+                question_msg = _(
+                    '"{path}" is a symlink. The linked target will not be '
+                    'backed up until you include it, too.\nWould you like '
+                    'to include the symlink target instead?') \
+                    .format(path=path)
+                if self.questionHandler(question_msg):
                     path = os.path.realpath(path)
 
             path = self.config.preparePath(path)
@@ -1891,7 +1928,7 @@ class SettingsDialog(QDialog):
             if old_path and old_path != path:
 
                 question = _('Are you sure you want to change '
-                             'snapshots folder ?')
+                             'snapshots folder?')
                 if not self.questionHandler(question):
                     return
 
@@ -1915,9 +1952,8 @@ class SettingsDialog(QDialog):
         if sshtools.sshKeyGen(key):
             self.txtSshPrivateKeyFile.setText(key)
         else:
-            self.errorHandler(
-                _('Failed to create new SSH key in %(path)s') % {'path': key}
-            )
+            self.errorHandler(_('Failed to create new SSH key in {path}')
+                              .format(path=key))
 
     def comboModesChanged(self, *params):
         if not params:
@@ -2085,33 +2121,17 @@ class RestoreConfigDialog(QDialog):
             snapshots.SID(datetime.datetime.now(), self.config).sid
         )
 
-        # inform user to join group fuse if he hasn't already.
-        # If there is no group fuse than it is most likly not nessesary.
-        addFuse = ''
-
-        try:
-            user = self.config.user()
-            fuse_grp_members = grp.getgrnam('fuse')[3]
-
-            if user not in fuse_grp_members:
-                addFuse = _(' and add your user to group \'fuse\'')
-
-        except KeyError:
-            pass
-
-        label = QLabel(
-            _('Please navigate to the snapshot from which you want '
-              'to restore %(appName)s\'s configuration. The path '
-              'may look like: \n%(samplePath)s\n\n'
-              'If your snapshots are on a remote drive or if they are '
-              'encrypted you need to manually mount them first. '
-              'If you use Mode SSH you also may need to set up public key '
-              'login to the remote host%(addFuse)s.\n'
-              'Take a look at \'man backintime\'.') % {
-                  'appName': self.config.APP_NAME,
-                  'samplePath': samplePath,
-                  'addFuse': addFuse
-              },
+        label = QLabel(_(
+            "Please navigate to the snapshot from which you want to restore "
+            "{appName}'s configuration. The path may look like:\n"
+            "{samplePath}\n\nIf your snapshots are on a remote drive or if "
+            "they are encrypted you need to manually mount them first. "
+            "If you use Mode SSH you also may need to set up public key "
+            "login to the remote host.\n"
+            "Take a look at 'man backintime'.")
+            .format(
+                appName=self.config.APP_NAME,
+                samplePath=samplePath),
             self
         )
         label.setWordWrap(True)
@@ -2216,9 +2236,9 @@ class RestoreConfigDialog(QDialog):
 
     def indexChanged(self, current, previous):
         """
-        called everytime a new item is choosen in treeView.
+        called every time a new item is chosen in treeView.
         If there was a config found inside the selected folder, show
-        available informations about the config.
+        available information about the config.
         """
         cfg = self.searchConfig(self.pathFromIndex(current))
         if cfg:
@@ -2286,9 +2306,9 @@ class RestoreConfigDialog(QDialog):
         for row, profileId in enumerate(cfg.profiles()):
 
             for col, txt in enumerate((
-                    _('Profile:') + ' ' + str(profileId),
+                    _('Profile') + ': ' + str(profileId),
                     cfg.profileName(profileId),
-                    _('Mode:') + ' ' + cfg.SNAPSHOT_MODES[
+                    _('Mode') + ': ' + cfg.SNAPSHOT_MODES[
                         cfg.snapshotsMode(profileId)][1]
                     )):
                 self.gridProfiles.addWidget(QLabel(txt, self), row, col)
@@ -2348,7 +2368,7 @@ class ScanFileSystem(QThread):
 
     def stop(self):
         """
-        prepair stop and wait for finish.
+        prepare stop and wait for finish.
         """
         self.stopper = True
         return self.wait()
